@@ -17,6 +17,7 @@
 
 package org.apache.zeppelin.spark;
 
+import org.apache.commons.lang3.StringUtils;
 import org.apache.zeppelin.display.AngularObjectRegistry;
 import org.apache.zeppelin.display.ui.CheckBox;
 import org.apache.zeppelin.display.ui.Password;
@@ -31,9 +32,9 @@ import org.apache.zeppelin.interpreter.InterpreterResult;
 import org.apache.zeppelin.interpreter.InterpreterResultMessageOutput;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterEventClient;
 import org.apache.zeppelin.interpreter.thrift.InterpreterCompletion;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.mockito.ArgumentCaptor;
 
 import java.io.IOException;
@@ -41,8 +42,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
@@ -50,7 +51,7 @@ import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.verify;
 
 
-public class SparkInterpreterTest {
+class SparkInterpreterTest {
 
   private SparkInterpreter interpreter;
 
@@ -61,13 +62,13 @@ public class SparkInterpreterTest {
 
   private RemoteInterpreterEventClient mockRemoteEventClient;
 
-  @Before
+  @BeforeEach
   public void setUp() {
     mockRemoteEventClient = mock(RemoteInterpreterEventClient.class);
   }
 
   @Test
-  public void testSparkInterpreter() throws IOException, InterruptedException, InterpreterException {
+  void testSparkInterpreter() throws IOException, InterruptedException, InterpreterException {
     Properties properties = new Properties();
     properties.setProperty(SparkStringConstants.MASTER_PROP_NAME, "local");
     properties.setProperty(SparkStringConstants.APP_NAME_PROP_NAME, "test");
@@ -90,7 +91,8 @@ public class SparkInterpreterTest {
 
     InterpreterResult result = interpreter.interpret("val a=\"hello world\"", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-    assertEquals("a: String = hello world\n", output);
+    // Use contains instead of equals, because there's behavior difference between different scala versions
+    assertTrue(output.contains("a: String = hello world\n"), output);
 
     result = interpreter.interpret("print(a)", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
@@ -122,9 +124,12 @@ public class SparkInterpreterTest {
     result = interpreter.interpret("/*comment here*/\nprint(\"hello world\")", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
 
-    // multiple line comment
-    result = interpreter.interpret("/*line 1 \n line 2*/", getInterpreterContext());
-    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
+    if (!interpreter.isScala213()) {
+      // multiple line comment, not supported by scala-2.13
+      context = getInterpreterContext();
+      result = interpreter.interpret("/*line 1 \n line 2*/", context);
+      assertEquals(InterpreterResult.Code.SUCCESS, result.code(), context.out.toString());
+    }
 
     // test function
     result = interpreter.interpret("def add(x:Int, y:Int)\n{ return x+y }", getInterpreterContext());
@@ -136,12 +141,6 @@ public class SparkInterpreterTest {
     result = interpreter.interpret("/*line 1 \n line 2*/print(\"hello world\")", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
 
-    // test $intp, only works for scala after 2.11
-    if (!interpreter.isScala210()) {
-      result = interpreter.interpret("$intp", getInterpreterContext());
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-    }
-
     // Companion object with case class
     result = interpreter.interpret("import scala.math._\n" +
         "object Circle {\n" +
@@ -155,6 +154,11 @@ public class SparkInterpreterTest {
         "val circle1 = new Circle(5.0)", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
 
+    // use case class in spark
+    //    context = getInterpreterContext();
+    //    result = interpreter.interpret("sc\n.range(1, 10)\n.map(e=>Circle(e))\n.collect()", context);
+    //    assertEquals(context.out.toString(), InterpreterResult.Code.SUCCESS, result.code());
+
     // class extend
     result = interpreter.interpret("import java.util.ArrayList", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
@@ -165,7 +169,7 @@ public class SparkInterpreterTest {
     // spark rdd operation
     context = getInterpreterContext();
     context.setParagraphId("pid_1");
-    result = interpreter.interpret("sc\n.range(1, 10)\n.sum", context);
+    result = interpreter.interpret("sc\n.range(1, 10)\n.map(e=>e)\n.sum", context);
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
     assertTrue(output.contains("45"));
     ArgumentCaptor<Map> captorEvent = ArgumentCaptor.forClass(Map.class);
@@ -188,10 +192,17 @@ public class SparkInterpreterTest {
     assertTrue(((String) onParaInfosReceivedArg.getValue().get("jobUrl")).startsWith("fake_spark_weburl/"
             + interpreter.getJavaSparkContext().sc().applicationId()));
 
-    // case class
+    // RDD of case class objects
+    result = interpreter.interpret(
+        "case class A(a: Integer, b: Integer)\n" +
+        "sc.parallelize(Seq(A(10, 20), A(30, 40))).collect()", getInterpreterContext());
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
+
+    // Dataset of case class objects
     result = interpreter.interpret("val bankText = sc.textFile(\"bank.csv\")", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
 
+    context = getInterpreterContext();
     result = interpreter.interpret(
         "case class Bank(age:Integer, job:String, marital : String, education : String, balance : Integer)\n" +
             "val bank = bankText.map(s=>s.split(\";\")).filter(s => s(0)!=\"\\\"age\\\"\").map(\n" +
@@ -201,8 +212,8 @@ public class SparkInterpreterTest {
             "            s(3).replaceAll(\"\\\"\", \"\"),\n" +
             "            s(5).replaceAll(\"\\\"\", \"\").toInt\n" +
             "        )\n" +
-            ").toDF()", getInterpreterContext());
-    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
+            ").toDF()", context);
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(), context.out.toString());
 
     // spark version
     result = interpreter.interpret("sc.version", getInterpreterContext());
@@ -210,51 +221,35 @@ public class SparkInterpreterTest {
 
     // spark sql test
     String version = output.trim();
-    if (version.contains("String = 1.")) {
-      result = interpreter.interpret("sqlContext", getInterpreterContext());
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
+    // create dataset from case class
+    context = getInterpreterContext();
+    result = interpreter.interpret("case class Person(id:Int, name:String, age:Int, country:String)\n" +
+            "val df2 = spark.createDataFrame(Seq(Person(1, \"andy\", 20, \"USA\"), " +
+            "Person(2, \"jeff\", 23, \"China\"), Person(3, \"james\", 18, \"USA\")))\n" +
+            "df2.printSchema\n" +
+            "df2.show() ", context);
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
 
-      result = interpreter.interpret(
-          "val df = sqlContext.createDataFrame(Seq((1,\"a\"),(2, null)))\n" +
-              "df.show()", getInterpreterContext());
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-      assertTrue(output.contains(
-          "+---+----+\n" +
-              "| _1|  _2|\n" +
-              "+---+----+\n" +
-              "|  1|   a|\n" +
-              "|  2|null|\n" +
-              "+---+----+"));
-    } else {
-      // create dataset from case class
-      context = getInterpreterContext();
-      result = interpreter.interpret("case class Person(id:Int, name:String, age:Int, country:String)\n" +
-              "val df2 = spark.createDataFrame(Seq(Person(1, \"andy\", 20, \"USA\"), " +
-              "Person(2, \"jeff\", 23, \"China\"), Person(3, \"james\", 18, \"USA\")))\n" +
-              "df2.printSchema\n" +
-              "df2.show() ", context);
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
+    result = interpreter.interpret("spark", getInterpreterContext());
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
 
-      result = interpreter.interpret("spark", getInterpreterContext());
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-
-      result = interpreter.interpret(
-          "val df = spark.createDataFrame(Seq((1,\"a\"),(2, null)))\n" +
-              "df.show()", getInterpreterContext());
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-      assertTrue(output.contains(
-          "+---+----+\n" +
-              "| _1|  _2|\n" +
-              "+---+----+\n" +
-              "|  1|   a|\n" +
-              "|  2|null|\n" +
-              "+---+----+"));
-    }
+    result = interpreter.interpret(
+        "val df = spark.createDataFrame(Seq((1,\"a\"),(2, null)))\n" +
+            "df.show()", getInterpreterContext());
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
+    // SPARK-43063 changed the output of null to NULL
+    assertTrue(StringUtils.containsIgnoreCase(output,
+        "+---+----+\n" +
+        "| _1|  _2|\n" +
+        "+---+----+\n" +
+        "|  1|   a|\n" +
+        "|  2|null|\n" +
+        "+---+----+"));
 
     // ZeppelinContext
     context = getInterpreterContext();
     result = interpreter.interpret("z.show(df)", context);
-    assertEquals(context.out.toString(), InterpreterResult.Code.SUCCESS, result.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code(), context.out.toString());
     assertEquals(InterpreterResult.Type.TABLE, messageOutput.getType());
     messageOutput.flush();
     assertEquals("_1\t_2\n1\ta\n2\tnull\n", messageOutput.toInterpreterResultMessage().getData());
@@ -306,7 +301,6 @@ public class SparkInterpreterTest {
     assertEquals("value_2", select.getOptions()[1].getValue());
     assertEquals("name_2", select.getOptions()[1].getDisplayName());
 
-
     // completions
     List<InterpreterCompletion> completions = interpreter.completion("a.", 2, getInterpreterContext());
     assertTrue(completions.size() > 0);
@@ -324,26 +318,29 @@ public class SparkInterpreterTest {
     assertEquals(1, completions.size());
     assertEquals("range", completions.get(0).name);
 
-    // Zeppelin-Display
-    result = interpreter.interpret("import org.apache.zeppelin.display.angular.notebookscope._\n" +
-        "import AngularElem._", getInterpreterContext());
-    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
+    if (!interpreter.isScala213()) {
+      // Zeppelin-Display
+      result = interpreter.interpret("import org.apache.zeppelin.display.angular.notebookscope._\n" +
+              "import AngularElem._", getInterpreterContext());
+      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
 
-    result = interpreter.interpret("<div style=\"color:blue\">\n" +
-        "<h4>Hello Angular Display System</h4>\n" +
-        "</div>.display", getInterpreterContext());
-    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-    assertEquals(InterpreterResult.Type.ANGULAR, messageOutput.getType());
-    assertTrue(messageOutput.toInterpreterResultMessage().getData().contains("Hello Angular Display System"));
+      context = getInterpreterContext();
+      result = interpreter.interpret("<div style=\"color:blue\">\n" +
+              "<h4>Hello Angular Display System</h4>\n" +
+              "</div>.display", context);
+      assertEquals(InterpreterResult.Code.SUCCESS, result.code(), context.out.toString());
+      assertEquals(InterpreterResult.Type.ANGULAR, messageOutput.getType());
+      assertTrue(messageOutput.toInterpreterResultMessage().getData().contains("Hello Angular Display System"));
 
-    result = interpreter.interpret("<div class=\"btn btn-success\">\n" +
-        "  Click me\n" +
-        "</div>.onClick{() =>\n" +
-        "  println(\"hello world\")\n" +
-        "}.display", getInterpreterContext());
-    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-    assertEquals(InterpreterResult.Type.ANGULAR, messageOutput.getType());
-    assertTrue(messageOutput.toInterpreterResultMessage().getData().contains("Click me"));
+      result = interpreter.interpret("<div class=\"btn btn-success\">\n" +
+              "  Click me\n" +
+              "</div>.onClick{() =>\n" +
+              "  println(\"hello world\")\n" +
+              "}.display", getInterpreterContext());
+      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
+      assertEquals(InterpreterResult.Type.ANGULAR, messageOutput.getType());
+      assertTrue(messageOutput.toInterpreterResultMessage().getData().contains("Click me"));
+    }
 
     // getProgress
     final InterpreterContext context2 = getInterpreterContext();
@@ -398,7 +395,7 @@ public class SparkInterpreterTest {
   }
 
   @Test
-  public void testDisableReplOutput() throws InterpreterException {
+  void testDisableReplOutput() throws InterpreterException {
     Properties properties = new Properties();
     properties.setProperty(SparkStringConstants.MASTER_PROP_NAME, "local");
     properties.setProperty(SparkStringConstants.APP_NAME_PROP_NAME, "test");
@@ -425,7 +422,7 @@ public class SparkInterpreterTest {
   }
 
   @Test
-  public void testDisableReplOutputForParagraph() throws InterpreterException {
+  void testDisableReplOutputForParagraph() throws InterpreterException {
     Properties properties = new Properties();
     properties.setProperty("spark.master", "local");
     properties.setProperty("spark.app.name", "test");
@@ -442,7 +439,8 @@ public class SparkInterpreterTest {
 
     InterpreterResult result = interpreter.interpret("val a=\"hello world\"", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-    assertEquals("a: String = hello world\n", output);
+    // Use contains instead of equals, because there's behavior different between different scala versions
+    assertTrue(output.contains("a: String = hello world\n"), output);
 
     result = interpreter.interpret("print(a)", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
@@ -460,7 +458,7 @@ public class SparkInterpreterTest {
     // REPL output get back if we don't set printREPLOutput in paragraph local properties
     result = interpreter.interpret("val a=\"hello world\"", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-    assertEquals("a: String = hello world\n", output);
+    assertTrue(output.contains("a: String = hello world\n"), output);
 
     result = interpreter.interpret("print(a)", getInterpreterContext());
     assertEquals(InterpreterResult.Code.SUCCESS, result.code());
@@ -469,7 +467,7 @@ public class SparkInterpreterTest {
   }
 
   @Test
-  public void testSchedulePool() throws InterpreterException {
+  void testSchedulePool() throws InterpreterException {
     Properties properties = new Properties();
     properties.setProperty(SparkStringConstants.MASTER_PROP_NAME, "local");
     properties.setProperty(SparkStringConstants.APP_NAME_PROP_NAME, "test");
@@ -498,7 +496,7 @@ public class SparkInterpreterTest {
 
   // spark.ui.enabled: false
   @Test
-  public void testDisableSparkUI_1() throws InterpreterException {
+  void testDisableSparkUI_1() throws InterpreterException {
     Properties properties = new Properties();
     properties.setProperty(SparkStringConstants.MASTER_PROP_NAME, "local");
     properties.setProperty(SparkStringConstants.APP_NAME_PROP_NAME, "test");
@@ -523,7 +521,7 @@ public class SparkInterpreterTest {
 
   // zeppelin.spark.ui.hidden: true
   @Test
-  public void testDisableSparkUI_2() throws InterpreterException {
+  void testDisableSparkUI_2() throws InterpreterException {
     Properties properties = new Properties();
     properties.setProperty(SparkStringConstants.MASTER_PROP_NAME, "local");
     properties.setProperty(SparkStringConstants.APP_NAME_PROP_NAME, "test");
@@ -547,7 +545,7 @@ public class SparkInterpreterTest {
   }
 
   @Test
-  public void testScopedMode() throws InterpreterException {
+  void testScopedMode() throws Exception {
     Properties properties = new Properties();
     properties.setProperty(SparkStringConstants.MASTER_PROP_NAME, "local");
     properties.setProperty(SparkStringConstants.APP_NAME_PROP_NAME, "test");
@@ -570,6 +568,9 @@ public class SparkInterpreterTest {
     interpreter1.open();
     interpreter2.open();
 
+    // check if there is any duplicated loaded class
+    assertEquals(true, interpreter1.getInnerInterpreter().getClass()==interpreter2.getInnerInterpreter().getClass());
+
     InterpreterContext context = getInterpreterContext();
 
     InterpreterResult result1 = interpreter1.interpret("sc.range(1, 10).sum", context);
@@ -586,7 +587,7 @@ public class SparkInterpreterTest {
     interpreter2.close();
   }
 
-  @After
+  @AfterEach
   public void tearDown() throws InterpreterException {
     if (this.interpreter != null) {
       this.interpreter.close();
