@@ -21,13 +21,11 @@ import org.apache.zeppelin.AbstractZeppelinIT;
 import org.apache.zeppelin.WebDriverManager;
 import org.apache.zeppelin.ZeppelinITUtils;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
-import org.hamcrest.CoreMatchers;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.ErrorCollector;
-
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.openqa.selenium.By;
 import org.openqa.selenium.WebElement;
 import org.openqa.selenium.support.ui.WebDriverWait;
@@ -37,16 +35,17 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import org.apache.commons.io.FileUtils;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.fail;
+
 import java.io.File;
 import java.io.IOException;
-
-import static org.junit.Assert.assertTrue;
+import java.time.Duration;
 
 public class PersonalizeActionsIT extends AbstractZeppelinIT {
   private static final Logger LOG = LoggerFactory.getLogger(PersonalizeActionsIT.class);
 
-  @Rule
-  public ErrorCollector collector = new ErrorCollector();
   static String shiroPath;
   static String authShiro = "[users]\n" +
       "admin = password1, admin\n" +
@@ -66,8 +65,18 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
 
   static String originalShiro = "";
 
-  @BeforeClass
-  public static void startUp() {
+  @BeforeEach
+  public void startUpManager() throws IOException {
+    manager = new WebDriverManager();
+  }
+
+  @AfterEach
+  public void tearDownManager() throws IOException {
+    manager.close();
+  }
+
+  @BeforeAll
+  public static void startUp() throws IOException {
     try {
       System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_HOME.getVarName(), new File("../").getAbsolutePath());
       ZeppelinConfiguration conf = ZeppelinConfiguration.create();
@@ -81,11 +90,10 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
       LOG.error("Error in PersonalizeActionsIT startUp::", e);
     }
     ZeppelinITUtils.restartZeppelin();
-    driver = WebDriverManager.getWebDriver();
   }
 
-  @AfterClass
-  public static void tearDown() {
+  @AfterAll
+  public static void tearDown() throws IOException {
     try {
       if (!StringUtils.isBlank(shiroPath)) {
         File file = new File(shiroPath);
@@ -99,7 +107,6 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
       LOG.error("Error in PersonalizeActionsIT tearDown::", e);
     }
     ZeppelinITUtils.restartZeppelin();
-    driver.quit();
   }
 
   private void setParagraphText(String text) {
@@ -109,7 +116,7 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
   }
 
   @Test
-  public void testSimpleAction() throws Exception {
+  void testSimpleAction() throws Exception {
     try {
       // step 1 : (admin) create a new note, run a paragraph and turn on personalized mode
       AuthenticationIT authenticationIT = new AuthenticationIT();
@@ -117,17 +124,20 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
       authenticationIT.authenticationUser("admin", "password1");
       By locator = By.xpath("//div[contains(@class, \"col-md-4\")]/div/h5/a[contains(.,'Create new" +
           " note')]");
-      WebDriverWait wait = new WebDriverWait(driver, MAX_BROWSER_TIMEOUT_SEC);
+      WebDriverWait wait =
+          new WebDriverWait(manager.getWebDriver(), Duration.ofSeconds(MAX_BROWSER_TIMEOUT_SEC));
       WebElement element = wait.until(ExpectedConditions.visibilityOfElementLocated(locator));
       if (element.isDisplayed()) {
         createNewNote();
       }
-      String noteId = driver.getCurrentUrl().substring(driver.getCurrentUrl().lastIndexOf("/") + 1);
+      String noteId = manager.getWebDriver().getCurrentUrl()
+          .substring(manager.getWebDriver().getCurrentUrl().lastIndexOf("/") + 1);
       waitForParagraph(1, "READY");
       personalizeActionsIT.setParagraphText("Before");
-      collector.checkThat("The output field paragraph contains",
-          driver.findElement(By.xpath(getParagraphXPath(1) + "//div[contains(@class, 'markdown-body')]")).getText(),
-          CoreMatchers.equalTo("Before"));
+      assertEquals("Before", manager.getWebDriver()
+          .findElement(
+              By.xpath(getParagraphXPath(1) + "//div[contains(@class, 'markdown-body')]"))
+          .getText());
       pollingWait(By.xpath("//*[@id='actionbar']" +
           "//button[contains(@uib-tooltip, 'Switch to personal mode')]"), MAX_BROWSER_TIMEOUT_SEC).click();
       clickAndWait(By.xpath("//div[@class='modal-dialog'][contains(.,'Do you want to personalize your analysis?')" +
@@ -137,21 +147,22 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
       // step 2 : (user1) make sure it is on personalized mode and 'Before' in result of paragraph
       authenticationIT.authenticationUser("user1", "password2");
       locator = By.xpath("//*[@id='notebook-names']//a[contains(@href, '" + noteId + "')]");
-      wait = new WebDriverWait(driver, MAX_BROWSER_TIMEOUT_SEC);
+      wait = new WebDriverWait(manager.getWebDriver(), Duration.ofSeconds(MAX_BROWSER_TIMEOUT_SEC));
       element = wait.until(ExpectedConditions.visibilityOfElementLocated(locator));
       if (element.isDisplayed()) {
         pollingWait(By.xpath("//*[@id='notebook-names']//a[contains(@href, '" + noteId + "')]"),
             MAX_BROWSER_TIMEOUT_SEC).click();
       }
-      collector.checkThat("The personalized mode enables",
-          driver.findElement(By.xpath("//*[@id='actionbar']" +
-              "//button[contains(@class, 'btn btn-default btn-xs ng-scope ng-hide')]")).getAttribute("uib-tooltip"),
-          CoreMatchers.equalTo("Switch to personal mode (owner can change)"));
+      assertEquals("Switch to personal mode (owner can change)",
+          manager.getWebDriver().findElement(By.xpath("//*[@id='actionbar']" +
+              "//button[contains(@class, 'btn btn-default btn-xs ng-scope ng-hide')]"))
+              .getAttribute("uib-tooltip"));
       waitForParagraph(1, "READY");
       runParagraph(1);
-      collector.checkThat("The output field paragraph contains",
-          driver.findElement(By.xpath(getParagraphXPath(1) + "//div[contains(@class, 'markdown-body')]")).getText(),
-          CoreMatchers.equalTo("Before"));
+      assertEquals("Before", manager.getWebDriver()
+          .findElement(
+              By.xpath(getParagraphXPath(1) + "//div[contains(@class, 'markdown-body')]"))
+          .getText());
       authenticationIT.logoutUser("user1");
 
       // step 3 : (admin) change paragraph contents to 'After' and check result of paragraph
@@ -163,9 +174,10 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
       }
       waitForParagraph(1, "FINISHED");
       personalizeActionsIT.setParagraphText("After");
-      collector.checkThat("The output field paragraph contains",
-          driver.findElement(By.xpath(getParagraphXPath(1) + "//div[contains(@class, 'markdown-body')]")).getText(),
-          CoreMatchers.equalTo("After"));
+      assertEquals("After", manager.getWebDriver()
+          .findElement(
+              By.xpath(getParagraphXPath(1) + "//div[contains(@class, 'markdown-body')]"))
+          .getText());
       authenticationIT.logoutUser("admin");
 
       // step 4 : (user1) check whether result is 'Before' or not
@@ -175,9 +187,10 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
       if (element.isDisplayed()) {
         pollingWait(By.xpath("//*[@id='notebook-names']//a[contains(@href, '" + noteId + "')]"), MAX_BROWSER_TIMEOUT_SEC).click();
       }
-      collector.checkThat("The output field paragraph contains",
-          driver.findElement(By.xpath(getParagraphXPath(1) + "//div[contains(@class, 'markdown-body')]")).getText(),
-          CoreMatchers.equalTo("Before"));
+      assertEquals("Before", manager.getWebDriver()
+          .findElement(
+              By.xpath(getParagraphXPath(1) + "//div[contains(@class, 'markdown-body')]"))
+          .getText());
       authenticationIT.logoutUser("user1");
     } catch (Exception e) {
       handleException("Exception in PersonalizeActionsIT while testSimpleAction ", e);
@@ -185,19 +198,21 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
   }
 
   @Test
-  public void testGraphAction() throws Exception {
+  void testGraphAction() throws Exception {
     try {
       // step 1 : (admin) create a new note, run a paragraph, change active graph to 'Bar chart', turn on personalized mode
       AuthenticationIT authenticationIT = new AuthenticationIT();
       authenticationIT.authenticationUser("admin", "password1");
       By locator = By.xpath("//div[contains(@class, \"col-md-4\")]/div/h5/a[contains(.,'Create new" +
           " note')]");
-      WebDriverWait wait = new WebDriverWait(driver, MAX_BROWSER_TIMEOUT_SEC);
+      WebDriverWait wait =
+          new WebDriverWait(manager.getWebDriver(), Duration.ofSeconds(MAX_BROWSER_TIMEOUT_SEC));
       WebElement element = wait.until(ExpectedConditions.visibilityOfElementLocated(locator));
       if (element.isDisplayed()) {
         createNewNote();
       }
-      String noteId = driver.getCurrentUrl().substring(driver.getCurrentUrl().lastIndexOf("/") + 1);
+      String noteId = manager.getWebDriver().getCurrentUrl()
+          .substring(manager.getWebDriver().getCurrentUrl().lastIndexOf("/") + 1);
       setTextOfParagraph(1, "%python print(\"%table " +
               "name\\\\tsize\\\\n" +
               "sun\\\\t100\\\\n" +
@@ -208,8 +223,8 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
         waitForParagraph(1, "FINISHED");
       } catch (TimeoutException e) {
         waitForParagraph(1, "ERROR");
-        collector.checkThat("Exception in PersonalizeActionsIT while testGraphAction, status of 1st Spark Paragraph ",
-            "ERROR", CoreMatchers.equalTo("FINISHED"));
+        fail(
+            "Exception in PersonalizeActionsIT while testGraphAction, status of 1st Spark Paragraph ");
       }
 
       pollingWait(By.xpath("//*[@id='actionbar']" +
@@ -219,13 +234,13 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
 
       pollingWait(By.xpath(getParagraphXPath(1) +
           "//button[contains(@uib-tooltip, 'Bar Chart')]"), MAX_BROWSER_TIMEOUT_SEC).click();
-      collector.checkThat("The output of graph mode is changed",
-          driver.findElement(By.xpath(getParagraphXPath(1) + "//button[contains(@class," +
-              "'btn btn-default btn-sm ng-binding ng-scope active')]//i")).getAttribute("class"),
-          CoreMatchers.equalTo("fa fa-bar-chart"));
+      assertEquals("fa fa-bar-chart",
+          manager.getWebDriver().findElement(By.xpath(getParagraphXPath(1)
+              + "//button[contains(@class," +
+              "'btn btn-default btn-sm ng-binding ng-scope active')]//i")).getAttribute("class"));
 
       authenticationIT.logoutUser("admin");
-      driver.navigate().refresh();
+      manager.getWebDriver().navigate().refresh();
 
       // step 2 : (user1) make sure it is on personalized mode and active graph is 'Bar chart',
       // try to change active graph to 'Table' and then check result
@@ -236,24 +251,22 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
         pollingWait(By.xpath("//*[@id='notebook-names']//a[contains(@href, '" + noteId + "')]"),
             MAX_BROWSER_TIMEOUT_SEC).click();
       }
-      collector.checkThat("The personalized mode enables",
-          driver.findElement(By.xpath("//*[@id='actionbar']" +
-              "//button[contains(@class, 'btn btn-default btn-xs ng-scope ng-hide')]")).getAttribute("uib-tooltip"),
-          CoreMatchers.equalTo("Switch to personal mode (owner can change)"));
-
-      collector.checkThat("Make sure the output of graph mode is",
-          driver.findElement(By.xpath(getParagraphXPath(1) + "//button[contains(@class," +
-              "'btn btn-default btn-sm ng-binding ng-scope active')]//i")).getAttribute("class"),
-          CoreMatchers.equalTo("fa fa-bar-chart"));
+      assertEquals("Switch to personal mode (owner can change)",
+          manager.getWebDriver().findElement(By.xpath("//*[@id='actionbar']" +
+              "//button[contains(@class, 'btn btn-default btn-xs ng-scope ng-hide')]"))
+              .getAttribute("uib-tooltip"));
+      assertEquals("fa fa-bar-chart",
+          manager.getWebDriver().findElement(By.xpath(getParagraphXPath(1)
+              + "//button[contains(@class," +
+              "'btn btn-default btn-sm ng-binding ng-scope active')]//i")).getAttribute("class"));
 
       pollingWait(By.xpath(getParagraphXPath(1) +
           "//button[contains(@uib-tooltip, 'Table')]"), MAX_BROWSER_TIMEOUT_SEC).click();
-      collector.checkThat("Change to table",
-          driver.findElement(By.xpath(getParagraphXPath(1) + "//button[contains(@class," +
-              "'btn btn-default btn-sm ng-binding ng-scope active')]//i")).getAttribute("class"),
-          CoreMatchers.equalTo("fa fa-table"));
+      assertEquals("fa fa-table", manager.getWebDriver().findElement(By.xpath(getParagraphXPath(1)
+          + "//button[contains(@class," +
+          "'btn btn-default btn-sm ng-binding ng-scope active')]//i")).getAttribute("class"));
       authenticationIT.logoutUser("user1");
-      driver.navigate().refresh();
+      manager.getWebDriver().navigate().refresh();
 
       // step 3: (admin) Admin view is still table because of it's personalized!
       authenticationIT.authenticationUser("admin", "password1");
@@ -263,11 +276,10 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
         pollingWait(By.xpath("//*[@id='notebook-names']//a[contains(@href, '" + noteId + "')]"),
                 MAX_BROWSER_TIMEOUT_SEC).click();
       }
-
-      collector.checkThat("Make sure the output of graph mode is",
-              driver.findElement(By.xpath(getParagraphXPath(1) + "//button[contains(@class," +
-                      "'btn btn-default btn-sm ng-binding ng-scope active')]//i")).getAttribute("class"),
-              CoreMatchers.equalTo("fa fa-bar-chart"));
+      assertEquals("fa fa-bar-chart",
+          manager.getWebDriver().findElement(By.xpath(getParagraphXPath(1)
+              + "//button[contains(@class," +
+              "'btn btn-default btn-sm ng-binding ng-scope active')]//i")).getAttribute("class"));
 
       authenticationIT.logoutUser("admin");
     } catch (Exception e) {
@@ -276,33 +288,32 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
   }
 
   @Test
-  public void testDynamicFormAction() throws Exception {
+  void testDynamicFormAction() throws Exception {
     try {
       // step 1 : (admin) login, create a new note, run a paragraph with data of spark tutorial, logout.
       AuthenticationIT authenticationIT = new AuthenticationIT();
       authenticationIT.authenticationUser("admin", "password1");
       By locator = By.xpath("//div[contains(@class, \"col-md-4\")]/div/h5/a[contains(.,'Create new" +
           " note')]");
-      WebDriverWait wait = new WebDriverWait(driver, MAX_BROWSER_TIMEOUT_SEC);
+      WebDriverWait wait =
+          new WebDriverWait(manager.getWebDriver(), Duration.ofSeconds(MAX_BROWSER_TIMEOUT_SEC));
       WebElement element = wait.until(ExpectedConditions.visibilityOfElementLocated(locator));
       if (element.isDisplayed()) {
         createNewNote();
       }
-      String noteId = driver.getCurrentUrl().substring(driver.getCurrentUrl().lastIndexOf("/") + 1);
+      String noteId = manager.getWebDriver().getCurrentUrl()
+          .substring(manager.getWebDriver().getCurrentUrl().lastIndexOf("/") + 1);
       setTextOfParagraph(1, "%spark println(\"Status: \"+z.textbox(\"name\", \"Before\")) ");
       runParagraph(1);
       try {
         waitForParagraph(1, "FINISHED");
       } catch (TimeoutException e) {
         waitForParagraph(1, "ERROR");
-        collector.checkThat("Exception in PersonalizeActionsIT while testDynamicFormAction, status of 1st Spark Paragraph ",
-            "ERROR", CoreMatchers.equalTo("FINISHED"));
+        fail(
+            "Exception in PersonalizeActionsIT while testDynamicFormAction, status of 1st Spark Paragraph");
       }
-
-      collector.checkThat("The output of graph mode is changed",
-          driver.findElement(By.xpath(getParagraphXPath(1) +
-              "//input[contains(@name, 'name')]")).getAttribute("value"),
-          CoreMatchers.equalTo("Before"));
+      assertEquals("Before", manager.getWebDriver().findElement(By.xpath(getParagraphXPath(1) +
+          "//input[contains(@name, 'name')]")).getAttribute("value"));
 
       pollingWait(By.xpath("//*[@id='actionbar']" +
           "//button[contains(@uib-tooltip, 'Switch to personal mode')]"), MAX_BROWSER_TIMEOUT_SEC).click();
@@ -319,15 +330,13 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
         pollingWait(By.xpath("//*[@id='notebook-names']//a[contains(@href, '" + noteId + "')]"),
             MAX_BROWSER_TIMEOUT_SEC).click();
       }
-      collector.checkThat("The personalized mode enables",
-          driver.findElement(By.xpath("//*[@id='actionbar']" +
-              "//button[contains(@class, 'btn btn-default btn-xs ng-scope ng-hide')]")).getAttribute("uib-tooltip"),
-          CoreMatchers.equalTo("Switch to personal mode (owner can change)"));
+      assertEquals("Switch to personal mode (owner can change)",
+          manager.getWebDriver().findElement(By.xpath("//*[@id='actionbar']" +
+              "//button[contains(@class, 'btn btn-default btn-xs ng-scope ng-hide')]"))
+              .getAttribute("uib-tooltip"));
 
-      collector.checkThat("The output of graph mode is changed",
-          driver.findElement(By.xpath(getParagraphXPath(1) +
-              "//input[contains(@name, 'name')]")).getAttribute("value"),
-          CoreMatchers.equalTo("Before"));
+      assertEquals("Before", manager.getWebDriver().findElement(By.xpath(getParagraphXPath(1) +
+          "//input[contains(@name, 'name')]")).getAttribute("value"));
 
       pollingWait(By.xpath(getParagraphXPath(1) +
           "//input[contains(@name, 'name')]"), MAX_BROWSER_TIMEOUT_SEC).clear();
@@ -339,13 +348,14 @@ public class PersonalizeActionsIT extends AbstractZeppelinIT {
         waitForParagraph(1, "FINISHED");
       } catch (TimeoutException e) {
         waitForParagraph(1, "ERROR");
-        collector.checkThat("Exception in PersonalizeActionsIT while testDynamicFormAction, status of 1st Spark Paragraph ",
-            "ERROR", CoreMatchers.equalTo("FINISHED"));
+        fail(
+            "Exception in PersonalizeActionsIT while testDynamicFormAction, status of 1st Spark Paragraph ");
       }
 
-      collector.checkThat("The output of graph mode is changed",
-          driver.findElement(By.xpath(getParagraphXPath(1) + "//div[contains(@class, 'text plainTextContent')]")).getText(),
-          CoreMatchers.equalTo("Status: Before"));
+      assertEquals("Status: Before", manager.getWebDriver()
+          .findElement(By
+              .xpath(getParagraphXPath(1) + "//div[contains(@class, 'text plainTextContent')]"))
+          .getText());
       authenticationIT.logoutUser("user1");
 
     } catch (Exception e) {
