@@ -20,43 +20,39 @@ package org.apache.zeppelin.integration;
 
 import org.apache.zeppelin.AbstractZeppelinIT;
 import org.apache.zeppelin.ZeppelinITUtils;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.apache.zeppelin.WebDriverManager;
-import org.hamcrest.CoreMatchers;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.ErrorCollector;
 import org.openqa.selenium.By;
 import org.openqa.selenium.TimeoutException;
 import org.openqa.selenium.WebElement;
 import org.openqa.selenium.Keys;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
+import java.io.IOException;
 import java.util.List;
 
-public class SparkParagraphIT extends AbstractZeppelinIT {
-  private static final Logger LOG = LoggerFactory.getLogger(SparkParagraphIT.class);
+class SparkParagraphIT extends AbstractZeppelinIT {
 
-  @Rule
-  public ErrorCollector collector = new ErrorCollector();
-
-  @Before
-  public void startUp() {
-    driver = WebDriverManager.getWebDriver();
+  @BeforeEach
+  public void startUp() throws IOException {
+    manager = new WebDriverManager();
     createNewNote();
     waitForParagraph(1, "READY");
   }
 
-  @After
-  public void tearDown() {
-    deleteTestNotebook(driver);
-    driver.quit();
+  @AfterEach
+  public void tearDown() throws IOException {
+    deleteTestNotebook(manager.getWebDriver());
+    manager.close();
   }
 
   @Test
-  public void testSpark() throws Exception {
+  void testSpark() throws Exception {
     try {
       setTextOfParagraph(1, "sc.version");
       runParagraph(1);
@@ -68,7 +64,7 @@ public class SparkParagraphIT extends AbstractZeppelinIT {
       import org.apache.commons.io.IOUtils
       import java.net.URL
       import java.nio.charset.Charset
-      val bankText = sc.parallelize(IOUtils.toString(new URL("https://s3.amazonaws.com/apache-zeppelin/tutorial/bank/bank.csv"),Charset.forName("utf8")).split("\n"))
+      val bankText = sc.parallelize(IOUtils.toString(new URL("https://raw.githubusercontent.com/apache/zeppelin/master/testing/resources/bank.csv"),Charset.forName("utf8")).split("\n"))
       case class Bank(age: Integer, job: String, marital: String, education: String, balance: Integer)
 
       val bank = bankText.map(s => s.split(";")).filter(s => s(0) != "\"age\"").map(s => Bank(s(0).toInt,s(1).replaceAll("\"", ""),s(2).replaceAll("\"", ""),s(3).replaceAll("\"", ""),s(5).replaceAll("\"", "").toInt)).toDF()
@@ -77,7 +73,7 @@ public class SparkParagraphIT extends AbstractZeppelinIT {
       setTextOfParagraph(2, "import org.apache.commons.io.IOUtils\\n" +
           "import java.net.URL\\n" +
           "import java.nio.charset.Charset\\n" +
-          "val bankText = sc.parallelize(IOUtils.toString(new URL(\"https://s3.amazonaws.com/apache-zeppelin/tutorial/bank/bank.csv\"),Charset.forName(\"utf8\")).split(\"\\\\n\"))\\n" +
+          "val bankText = sc.parallelize(IOUtils.toString(new URL(\"https://raw.githubusercontent.com/apache/zeppelin/master/testing/resources/bank.csv\"),Charset.forName(\"utf8\")).split(\"\\\\n\"))\\n" +
           "case class Bank(age: Integer, job: String, marital: String, education: String, balance: Integer)\\n" +
           "\\n" +
           "val bank = bankText.map(s => s.split(\";\")).filter(s => s(0) != \"\\\\\"age\\\\\"\").map(s => Bank(s(0).toInt,s(1).replaceAll(\"\\\\\"\", \"\"),s(2).replaceAll(\"\\\\\"\", \"\"),s(3).replaceAll(\"\\\\\"\", \"\"),s(5).replaceAll(\"\\\\\"\", \"\").toInt)).toDF()\\n" +
@@ -88,27 +84,21 @@ public class SparkParagraphIT extends AbstractZeppelinIT {
         waitForParagraph(2, "FINISHED");
       } catch (TimeoutException e) {
         waitForParagraph(2, "ERROR");
-        collector.checkThat("2nd Paragraph from SparkParagraphIT of testSpark status:",
-            "ERROR", CoreMatchers.equalTo("FINISHED")
-        );
+        fail("2nd Paragraph from SparkParagraphIT of testSpark status:");
       }
 
-      WebElement paragraph2Result = driver.findElement(By.xpath(
+      WebElement paragraph2Result = manager.getWebDriver().findElement(By.xpath(
           getParagraphXPath(2) + "//div[contains(@id,\"_text\")]"));
 
-      collector.checkThat("2nd Paragraph from SparkParagraphIT of testSpark result: ",
-          paragraph2Result.getText().toString(), CoreMatchers.containsString(
-              "import org.apache.commons.io.IOUtils"
-          )
-      );
-
+      assertTrue(paragraph2Result.getText().contains("import org.apache.commons.io.IOUtils"),
+          paragraph2Result.getText());
     } catch (Exception e) {
       handleException("Exception in SparkParagraphIT while testSpark", e);
     }
   }
 
   @Test
-  public void testPySpark() throws Exception {
+  void testPySpark() throws Exception {
     try {
       setTextOfParagraph(1, "%pyspark\\n" +
           "for x in range(0, 3):\\n" +
@@ -120,16 +110,13 @@ public class SparkParagraphIT extends AbstractZeppelinIT {
         waitForParagraph(1, "FINISHED");
       } catch (TimeoutException e) {
         waitForParagraph(1, "ERROR");
-        collector.checkThat("Paragraph from SparkParagraphIT of testPySpark status: ",
-            "ERROR", CoreMatchers.equalTo("FINISHED")
-        );
+        fail("Paragraph from SparkParagraphIT of testPySpark status: ERROR");
       }
 
-      WebElement paragraph1Result = driver.findElement(By.xpath(
+      WebElement paragraph1Result = manager.getWebDriver().findElement(By.xpath(
           getParagraphXPath(1) + "//div[contains(@id,\"_text\")]"));
-      collector.checkThat("Paragraph from SparkParagraphIT of testPySpark result: ",
-          paragraph1Result.getText().toString(), CoreMatchers.containsString("test loop 0\ntest loop 1\ntest loop 2")
-      );
+      assertTrue(paragraph1Result.getText().contains("test loop 0\ntest loop 1\ntest loop 2"),
+          paragraph1Result.getText());
 
       // the last statement's evaluation result is printed
       setTextOfParagraph(2, "%pyspark\\n" +
@@ -140,15 +127,11 @@ public class SparkParagraphIT extends AbstractZeppelinIT {
         waitForParagraph(2, "FINISHED");
       } catch (TimeoutException e) {
         waitForParagraph(2, "ERROR");
-        collector.checkThat("Paragraph from SparkParagraphIT of testPySpark status: ",
-                "ERROR", CoreMatchers.equalTo("FINISHED")
-        );
+        fail("Paragraph from SparkParagraphIT of testPySpark status: ERROR");
       }
-      WebElement paragraph2Result = driver.findElement(By.xpath(
+      WebElement paragraph2Result = manager.getWebDriver().findElement(By.xpath(
               getParagraphXPath(2) + "//div[contains(@id,\"_text\")]"));
-      collector.checkThat("Paragraph from SparkParagraphIT of testPySpark result: ",
-          paragraph2Result.getText().toString(), CoreMatchers.equalTo("2")
-      );
+      assertEquals("2", paragraph2Result.getText(), "Paragraph from SparkParagraphIT of testPySpark result: " + paragraph2Result.getText());
 
     } catch (Exception e) {
       handleException("Exception in SparkParagraphIT while testPySpark", e);
@@ -156,19 +139,26 @@ public class SparkParagraphIT extends AbstractZeppelinIT {
   }
 
   @Test
-  public void testCancelPyspark() throws Exception {
+  void testCancelPyspark() throws Exception {
     try {
       setTextOfParagraph(1, "%pyspark\\nimport time\\nfor i in range(0, 30):\\n\\ttime.sleep(1)");
-      driver.findElement(By.xpath(getParagraphXPath(1) + "//span[@class='icon-settings']")).click();
-      driver.findElement(By.xpath(getParagraphXPath(1) + "//ul/li/a[@ng-click=\"insertNew('below')\"]"))
+      manager.getWebDriver()
+          .findElement(By.xpath(getParagraphXPath(1) + "//span[@class='icon-settings']")).click();
+      manager.getWebDriver()
+          .findElement(
+              By.xpath(getParagraphXPath(1) + "//ul/li/a[@ng-click=\"insertNew('below')\"]"))
               .click();
       waitForParagraph(2, "READY");
       setTextOfParagraph(2, "%pyspark\\nprint(\"Hello World!\")");
 
 
-      driver.findElement(By.xpath(".//*[@id='main']//button[contains(@ng-click, 'runAllParagraphs')]")).sendKeys(Keys.ENTER);
+      manager.getWebDriver()
+          .findElement(
+              By.xpath(".//*[@id='main']//button[contains(@ng-click, 'runAllParagraphs')]"))
+          .sendKeys(Keys.ENTER);
       ZeppelinITUtils.sleep(1000, false);
-      driver.findElement(By.xpath("//div[@class='modal-dialog'][contains(.,'Run all paragraphs?')]" +
+      manager.getWebDriver()
+          .findElement(By.xpath("//div[@class='modal-dialog'][contains(.,'Run all paragraphs?')]" +
               "//div[@class='modal-footer']//button[contains(.,'OK')]")).click();
       waitForParagraph(1, "RUNNING");
 
@@ -176,16 +166,12 @@ public class SparkParagraphIT extends AbstractZeppelinIT {
       cancelParagraph(1);
       waitForParagraph(1, "ABORT");
 
-      collector.checkThat("First paragraph status is ",
-              getParagraphStatus(1), CoreMatchers.equalTo("ABORT")
-      );
+      assertEquals("ABORT", getParagraphStatus(1),
+          "First paragraph status is " + getParagraphStatus(1));
+      assertEquals("READY", getParagraphStatus(2),
+          "Second paragraph status is " + getParagraphStatus(2));
 
-      collector.checkThat("Second paragraph status is ",
-              getParagraphStatus(2), CoreMatchers.either(CoreMatchers.equalTo("PENDING"))
-                      .or(CoreMatchers.equalTo("READY"))
-      );
-
-      driver.navigate().refresh();
+      manager.getWebDriver().navigate().refresh();
       ZeppelinITUtils.sleep(3000, false);
 
     } catch (Exception e) {
@@ -194,7 +180,7 @@ public class SparkParagraphIT extends AbstractZeppelinIT {
   }
 
   @Test
-  public void testSqlSpark() throws Exception {
+  void testSqlSpark() throws Exception {
     try {
       setTextOfParagraph(1,"%sql\\n" +
           "select * from bank limit 1");
@@ -204,21 +190,20 @@ public class SparkParagraphIT extends AbstractZeppelinIT {
         waitForParagraph(1, "FINISHED");
       } catch (TimeoutException e) {
         waitForParagraph(1, "ERROR");
-        collector.checkThat("Paragraph from SparkParagraphIT of testSqlSpark status: ",
-            "ERROR", CoreMatchers.equalTo("FINISHED")
-        );
+        fail("Paragraph from SparkParagraphIT of testSqlSpark status: ERROR");
       }
 
       // Age, Job, Marital, Education, Balance
-      List<WebElement> tableHeaders = driver.findElements(By.cssSelector("span.ui-grid-header-cell-label"));
+      List<WebElement> tableHeaders =
+          manager.getWebDriver().findElements(By.cssSelector("span.ui-grid-header-cell-label"));
       String headerNames = "";
 
       for(WebElement header : tableHeaders) {
         headerNames += header.getText().toString() + "|";
       }
 
-      collector.checkThat("Paragraph from SparkParagraphIT of testSqlSpark result: ",
-          headerNames, CoreMatchers.equalTo("age|job|marital|education|balance|"));
+      assertEquals("age|job|marital|education|balance|", headerNames,
+          "Paragraph from SparkParagraphIT of testSqlSpark result: " + headerNames);
     } catch (Exception e) {
       handleException("Exception in SparkParagraphIT while testSqlSpark", e);
     }
@@ -237,33 +222,32 @@ public class SparkParagraphIT extends AbstractZeppelinIT {
 
       try {
         waitForParagraph(1, "FINISHED");
-        WebElement paragraph1Result = driver.findElement(By.xpath(getParagraphXPath(1) +
+        WebElement paragraph1Result =
+            manager.getWebDriver().findElement(By.xpath(getParagraphXPath(1) +
             "//div[contains(@id,'_text')]"));
-        collector.checkThat("Paragraph from SparkParagraphIT of testSqlSpark result: ",
-            paragraph1Result.getText(), CoreMatchers.containsString("res0: org.apache.zeppelin.dep.Dependency = org.apache.zeppelin.dep.Dependency"));
-
+        assertTrue(
+            paragraph1Result.getText().contains(
+                "res0: org.apache.zeppelin.dep.Dependency = org.apache.zeppelin.dep.Dependency"),
+            paragraph1Result.getText());
         setTextOfParagraph(2, "import org.apache.commons.csv.CSVFormat");
         runParagraph(2);
 
         try {
           waitForParagraph(2, "FINISHED");
-          WebElement paragraph2Result = driver.findElement(By.xpath(getParagraphXPath(2) +
+          WebElement paragraph2Result =
+              manager.getWebDriver().findElement(By.xpath(getParagraphXPath(2) +
               "//div[contains(@id,'_text')]"));
-          collector.checkThat("Paragraph from SparkParagraphIT of testSqlSpark result: ",
-              paragraph2Result.getText(), CoreMatchers.equalTo("import org.apache.commons.csv.CSVFormat"));
-
+          assertEquals("import org.apache.commons.csv.CSVFormat", paragraph2Result.getText(),
+              "Paragraph from SparkParagraphIT of testSqlSpark result: "
+                  + paragraph2Result.getText());
         } catch (TimeoutException e) {
           waitForParagraph(2, "ERROR");
-          collector.checkThat("Second paragraph from SparkParagraphIT of testDep status: ",
-              "ERROR", CoreMatchers.equalTo("FINISHED")
-          );
+          fail("Second paragraph from SparkParagraphIT of testDep status: ERROR");
         }
 
       } catch (TimeoutException e) {
         waitForParagraph(1, "ERROR");
-        collector.checkThat("First paragraph from SparkParagraphIT of testDep status: ",
-            "ERROR", CoreMatchers.equalTo("FINISHED")
-        );
+        fail("First paragraph from SparkParagraphIT of testDep status: ERROR");
       }
     } catch (Exception e) {
       handleException("Exception in SparkParagraphIT while testDep", e);
