@@ -17,9 +17,12 @@
 
 package org.apache.zeppelin.integration;
 
+import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.IOUtils;
 import org.apache.hadoop.yarn.api.protocolrecords.GetApplicationsRequest;
 import org.apache.hadoop.yarn.api.protocolrecords.GetApplicationsResponse;
+import org.apache.hadoop.yarn.api.records.ApplicationReport;
+import org.apache.hadoop.yarn.api.records.FinalApplicationStatus;
 import org.apache.hadoop.yarn.api.records.YarnApplicationState;
 import org.apache.hadoop.yarn.exceptions.YarnException;
 import org.apache.maven.model.Model;
@@ -29,28 +32,30 @@ import org.apache.zeppelin.interpreter.Interpreter;
 import org.apache.zeppelin.interpreter.InterpreterContext;
 import org.apache.zeppelin.interpreter.InterpreterException;
 import org.apache.zeppelin.interpreter.InterpreterFactory;
-import org.apache.zeppelin.interpreter.InterpreterNotFoundException;
 import org.apache.zeppelin.interpreter.InterpreterOption;
 import org.apache.zeppelin.interpreter.InterpreterResult;
 import org.apache.zeppelin.interpreter.InterpreterSetting;
 import org.apache.zeppelin.interpreter.InterpreterSettingManager;
 import org.apache.zeppelin.interpreter.integration.DownloadUtils;
 import org.codehaus.plexus.util.xml.pull.XmlPullParserException;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
+
 import java.io.File;
 import java.io.FileReader;
 import java.io.IOException;
+import java.nio.charset.StandardCharsets;
 import java.util.EnumSet;
-
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertTrue;
-
+import java.util.List;
+import java.util.stream.Collectors;
 
 public abstract class SparkIntegrationTest {
   private static Logger LOGGER = LoggerFactory.getLogger(SparkIntegrationTest.class);
@@ -61,16 +66,18 @@ public abstract class SparkIntegrationTest {
   protected static InterpreterSettingManager interpreterSettingManager;
 
   private String sparkVersion;
+  private String hadoopVersion;
   private String sparkHome;
 
-  public SparkIntegrationTest(String sparkVersion, String hadoopVersion) {
+  public void prepareSpark(String sparkVersion, String hadoopVersion) {
     LOGGER.info("Testing Spark Version: " + sparkVersion);
     LOGGER.info("Testing Hadoop Version: " + hadoopVersion);
     this.sparkVersion = sparkVersion;
+    this.hadoopVersion = hadoopVersion;
     this.sparkHome = DownloadUtils.downloadSpark(sparkVersion, hadoopVersion);
   }
 
-  @BeforeClass
+  @BeforeAll
   public static void setUp() throws IOException {
     hadoopCluster = new MiniHadoopCluster();
     hadoopCluster.start();
@@ -81,7 +88,7 @@ public abstract class SparkIntegrationTest {
     interpreterSettingManager = zeppelin.getInterpreterSettingManager();
   }
 
-  @AfterClass
+  @AfterAll
   public static void tearDown() throws IOException {
     if (zeppelin != null) {
       zeppelin.stop();
@@ -92,13 +99,44 @@ public abstract class SparkIntegrationTest {
   }
 
   protected void setUpSparkInterpreterSetting(InterpreterSetting interpreterSetting) {
-    // sub class can customize spark interpreter setting.
+    if (isSpark3()) {
+      // spark3 doesn't support yarn-client and yarn-cluster anymore, use
+      // spark.master and spark.submit.deployMode instead
+      String sparkMaster = interpreterSetting.getJavaProperties().getProperty("spark.master");
+      if (sparkMaster.equals("yarn-client")) {
+        interpreterSetting.setProperty("spark.master", "yarn");
+        interpreterSetting.setProperty("spark.submit.deployMode", "client");
+      } else if (sparkMaster.equals("yarn-cluster")){
+        interpreterSetting.setProperty("spark.master", "yarn");
+        interpreterSetting.setProperty("spark.submit.deployMode", "cluster");
+      } else if (sparkMaster.startsWith("local")) {
+        interpreterSetting.setProperty("spark.submit.deployMode", "client");
+      }
+    }
+  }
+
+  /**
+   * Configures ivy to download jar libraries only from remote.
+   *
+   * @param interpreterSetting
+   * @throws IOException
+   */
+  private void setupIvySettings(InterpreterSetting interpreterSetting) throws IOException {
+    File ivysettings = new File(zeppelin.getZeppelinConfDir(), "ivysettings.xml");
+    FileUtils.copyToFile(SparkIntegrationTest.class.getResourceAsStream("/ivysettings.xml"), ivysettings);
+    interpreterSetting.setProperty("spark.jars.ivySettings", ivysettings.getAbsolutePath());
+  }
+
+  private boolean isHadoopVersionMatch() {
+    String version = org.apache.hadoop.util.VersionInfo.getVersion();
+    String majorVersion = version.split("\\.")[0];
+    return majorVersion.equals(hadoopVersion.split("\\.")[0]);
   }
 
   private void testInterpreterBasics() throws IOException, InterpreterException, XmlPullParserException {
     // add jars & packages for testing
     InterpreterSetting sparkInterpreterSetting = interpreterSettingManager.getInterpreterSettingByName("spark");
-    sparkInterpreterSetting.setProperty("spark.jars.packages", "com.maxmind.geoip2:geoip2:2.5.0");
+    sparkInterpreterSetting.setProperty("spark.jars.packages", "com.maxmind.geoip2:geoip2:2.16.1");
     sparkInterpreterSetting.setProperty("SPARK_PRINT_LAUNCH_COMMAND", "true");
     sparkInterpreterSetting.setProperty("zeppelin.python.gatewayserver_address", "127.0.0.1");
 
@@ -111,53 +149,51 @@ public abstract class SparkIntegrationTest {
 
     InterpreterContext context = new InterpreterContext.Builder().setNoteId("note1").setParagraphId("paragraph_1").build();
     InterpreterResult interpreterResult = sparkInterpreter.interpret("sc.version", context);
-    assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
     String detectedSparkVersion = interpreterResult.message().get(0).getData();
-    assertTrue(detectedSparkVersion + " doesn't contain " + this.sparkVersion, detectedSparkVersion.contains(this.sparkVersion));
+    assertTrue(detectedSparkVersion.contains(this.sparkVersion), detectedSparkVersion + " doesn't contain " + this.sparkVersion);
     interpreterResult = sparkInterpreter.interpret("sc.range(1,10).sum()", context);
-    assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
-    assertTrue(interpreterResult.toString(), interpreterResult.message().get(0).getData().contains("45"));
+    assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
+    assertTrue(interpreterResult.message().get(0).getData().contains("45"), interpreterResult.toString());
 
     interpreterResult = sparkInterpreter.interpret("sc.getConf.get(\"spark.user.name\")", context);
-    assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
-    assertTrue(interpreterResult.toString(), interpreterResult.message().get(0).getData().contains("user1"));
+    assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
+    assertTrue(interpreterResult.message().get(0).getData().contains("user1"), interpreterResult.toString());
 
     // test jars & packages can be loaded correctly
     interpreterResult = sparkInterpreter.interpret("import org.apache.zeppelin.interpreter.integration.DummyClass\n" +
             "import com.maxmind.geoip2._", context);
-    assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
 
     // test PySparkInterpreter
     Interpreter pySparkInterpreter = interpreterFactory.getInterpreter("spark.pyspark", new ExecutionContext("user1", "note1", "test"));
     interpreterResult = pySparkInterpreter.interpret("sqlContext.createDataFrame([(1,'a'),(2,'b')], ['id','name']).registerTempTable('test')", context);
-    assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
 
     // test IPySparkInterpreter
     Interpreter ipySparkInterpreter = interpreterFactory.getInterpreter("spark.ipyspark", new ExecutionContext("user1", "note1", "test"));
     interpreterResult = ipySparkInterpreter.interpret("sqlContext.table('test').show()", context);
-    assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
+    assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
 
     // test SparkSQLInterpreter
     Interpreter sqlInterpreter = interpreterFactory.getInterpreter("spark.sql", new ExecutionContext("user1", "note1", "test"));
     interpreterResult = sqlInterpreter.interpret("select count(1) as c from test", context);
-    assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
-    assertEquals(interpreterResult.toString(), InterpreterResult.Type.TABLE, interpreterResult.message().get(0).getType());
-    assertEquals(interpreterResult.toString(), "c\n2\n", interpreterResult.message().get(0).getData());
+    assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
+    assertEquals(InterpreterResult.Type.TABLE, interpreterResult.message().get(0).getType(), interpreterResult.toString());
+    assertEquals("c\n2\n", interpreterResult.message().get(0).getData(), interpreterResult.toString());
 
     // test SparkRInterpreter
     Interpreter sparkrInterpreter = interpreterFactory.getInterpreter("spark.r", new ExecutionContext("user1", "note1", "test"));
-    if (isSpark2() || isSpark3()) {
-      interpreterResult = sparkrInterpreter.interpret("df <- as.DataFrame(faithful)\nhead(df)", context);
-    } else {
-      interpreterResult = sparkrInterpreter.interpret("df <- createDataFrame(sqlContext, faithful)\nhead(df)", context);
-    }
-    assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
-    assertEquals(interpreterResult.toString(), InterpreterResult.Type.TEXT, interpreterResult.message().get(0).getType());
-    assertTrue(interpreterResult.toString(), interpreterResult.message().get(0).getData().contains("eruptions waiting"));
+    interpreterResult = sparkrInterpreter.interpret("df <- as.DataFrame(faithful)\nhead(df)", context);
+    assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
+    assertEquals(InterpreterResult.Type.TEXT, interpreterResult.message().get(0).getType(), interpreterResult.toString());
+    assertTrue( interpreterResult.message().get(0).getData().contains("eruptions waiting"), interpreterResult.toString());
   }
 
   @Test
   public void testLocalMode() throws IOException, YarnException, InterpreterException, XmlPullParserException {
+    assumeTrue(isHadoopVersionMatch(),"Hadoop version mismatch, skip test");
+
     InterpreterSetting sparkInterpreterSetting = interpreterSettingManager.getInterpreterSettingByName("spark");
     sparkInterpreterSetting.setProperty("spark.master", "local[*]");
     sparkInterpreterSetting.setProperty("SPARK_HOME", sparkHome);
@@ -170,6 +206,7 @@ public abstract class SparkIntegrationTest {
 
     try {
       setUpSparkInterpreterSetting(sparkInterpreterSetting);
+      setupIvySettings(sparkInterpreterSetting);
       testInterpreterBasics();
 
       // no yarn application launched
@@ -183,6 +220,8 @@ public abstract class SparkIntegrationTest {
 
   @Test
   public void testYarnClientMode() throws IOException, YarnException, InterruptedException, InterpreterException, XmlPullParserException {
+    assumeTrue(isHadoopVersionMatch(), "Hadoop version mismatch, skip test");
+
     InterpreterSetting sparkInterpreterSetting = interpreterSettingManager.getInterpreterSettingByName("spark");
     sparkInterpreterSetting.setProperty("spark.master", "yarn-client");
     sparkInterpreterSetting.setProperty("HADOOP_CONF_DIR", hadoopCluster.getConfigPath());
@@ -199,6 +238,7 @@ public abstract class SparkIntegrationTest {
 
     try {
       setUpSparkInterpreterSetting(sparkInterpreterSetting);
+      setupIvySettings(sparkInterpreterSetting);
       testInterpreterBasics();
 
       // 1 yarn application launched
@@ -228,11 +268,13 @@ public abstract class SparkIntegrationTest {
         e.printStackTrace();
       }
     }
-    assertTrue("Yarn app is not completed in " + timeout + " milliseconds.", yarnAppCompleted);
+    assertTrue(yarnAppCompleted, "Yarn app is not completed in " + timeout + " milliseconds.");
   }
 
   @Test
   public void testYarnClusterMode() throws IOException, YarnException, InterruptedException, InterpreterException, XmlPullParserException {
+    assumeTrue(isHadoopVersionMatch(), "Hadoop version mismatch, skip test");
+
     InterpreterSetting sparkInterpreterSetting = interpreterSettingManager.getInterpreterSettingByName("spark");
     sparkInterpreterSetting.setProperty("spark.master", "yarn-cluster");
     sparkInterpreterSetting.setProperty("HADOOP_CONF_DIR", hadoopCluster.getConfigPath());
@@ -249,8 +291,10 @@ public abstract class SparkIntegrationTest {
     // parameters with whitespace
     sparkInterpreterSetting.setProperty("spark.app.name", "hello spark");
 
+    String yarnAppId = null;
     try {
       setUpSparkInterpreterSetting(sparkInterpreterSetting);
+      setupIvySettings(sparkInterpreterSetting);
       testInterpreterBasics();
 
       // 1 yarn application launched
@@ -258,15 +302,27 @@ public abstract class SparkIntegrationTest {
       GetApplicationsResponse response = hadoopCluster.getYarnCluster().getResourceManager().getClientRMService().getApplications(request);
       assertEquals(1, response.getApplicationList().size());
       assertEquals("hello spark", response.getApplicationList().get(0).getName());
-
+      yarnAppId = response.getApplicationList().get(0).getApplicationId().toString();
     } finally {
       interpreterSettingManager.close();
       waitForYarnAppCompleted(30 * 1000);
+
+      if (yarnAppId != null) {
+        // ensure yarn app is finished with SUCCEEDED status.
+        final String finalYarnAppId = yarnAppId;
+        GetApplicationsRequest request = GetApplicationsRequest.newInstance(EnumSet.of(YarnApplicationState.FINISHED));
+        GetApplicationsResponse response = hadoopCluster.getYarnCluster().getResourceManager().getClientRMService().getApplications(request);
+        List<ApplicationReport> apps = response.getApplicationList().stream().filter(app -> app.getApplicationId().toString().equals(finalYarnAppId)).collect(Collectors.toList());
+        assertEquals(1, apps.size());
+        assertEquals(FinalApplicationStatus.SUCCEEDED, apps.get(0).getFinalApplicationStatus());
+      }
     }
   }
 
   @Test
   public void testSparkSubmit() throws InterpreterException {
+    assumeTrue(isHadoopVersionMatch(), "Hadoop version mismatch, skip test");
+
     try {
       InterpreterSetting sparkSubmitInterpreterSetting = interpreterSettingManager.getInterpreterSettingByName("spark-submit");
       sparkSubmitInterpreterSetting.setProperty("SPARK_HOME", sparkHome);
@@ -275,7 +331,7 @@ public abstract class SparkIntegrationTest {
       Interpreter sparkSubmitInterpreter = interpreterFactory.getInterpreter("spark-submit", new ExecutionContext("user1", "note1", "test"));
       InterpreterResult interpreterResult = sparkSubmitInterpreter.interpret("--class org.apache.spark.examples.SparkPi " + sparkHome + "/examples/jars/spark-examples*.jar ", context);
 
-      assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
+      assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
     } finally {
       interpreterSettingManager.close();
     }
@@ -283,6 +339,8 @@ public abstract class SparkIntegrationTest {
 
   @Test
   public void testScopedMode() throws InterpreterException {
+    assumeTrue(isHadoopVersionMatch(), "Hadoop version mismatch, skip test");
+
     InterpreterSetting sparkInterpreterSetting = interpreterSettingManager.getInterpreterSettingByName("spark");
     try {
       sparkInterpreterSetting.setProperty("spark.master", "local[*]");
@@ -300,16 +358,16 @@ public abstract class SparkIntegrationTest {
 
       InterpreterContext context = new InterpreterContext.Builder().setNoteId("note1").setParagraphId("paragraph_1").build();
       InterpreterResult interpreterResult = sparkInterpreter1.interpret("sc.range(1,10).map(e=>e+1).sum()", context);
-      assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
-      assertTrue(interpreterResult.toString(), interpreterResult.message().get(0).getData().contains("54"));
+      assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
+      assertTrue(interpreterResult.message().get(0).getData().contains("54"), interpreterResult.toString());
 
       Interpreter sparkInterpreter2 = interpreterFactory.getInterpreter("spark.spark", new ExecutionContext("user1", "note2", "test"));
       assertNotEquals(sparkInterpreter1, sparkInterpreter2);
 
       context = new InterpreterContext.Builder().setNoteId("note2").setParagraphId("paragraph_1").build();
       interpreterResult = sparkInterpreter2.interpret("sc.range(1,10).map(e=>e+1).sum()", context);
-      assertEquals(interpreterResult.toString(), InterpreterResult.Code.SUCCESS, interpreterResult.code());
-      assertTrue(interpreterResult.toString(), interpreterResult.message().get(0).getData().contains("54"));
+      assertEquals(InterpreterResult.Code.SUCCESS, interpreterResult.code(), interpreterResult.toString());
+      assertTrue(interpreterResult.message().get(0).getData().contains("54"), interpreterResult.toString());
     } finally {
       interpreterSettingManager.close();
 
@@ -319,11 +377,7 @@ public abstract class SparkIntegrationTest {
       }
     }
   }
-
-  private boolean isSpark2() {
-    return this.sparkVersion.startsWith("2.");
-  }
-
+  
   private boolean isSpark3() {
     return this.sparkVersion.startsWith("3.");
   }
@@ -333,6 +387,6 @@ public abstract class SparkIntegrationTest {
     if (process.waitFor() != 0) {
       throw new RuntimeException("Fail to run command: which python.");
     }
-    return IOUtils.toString(process.getInputStream()).trim();
+    return IOUtils.toString(process.getInputStream(), StandardCharsets.UTF_8).trim();
   }
 }
