@@ -27,31 +27,31 @@ import org.apache.zeppelin.client.ZeppelinClient;
 
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.common.SessionInfo;
-import org.apache.zeppelin.notebook.Note;
 import org.apache.zeppelin.notebook.Notebook;
 import org.apache.zeppelin.rest.AbstractTestRestApi;
 import org.apache.zeppelin.utils.TestUtils;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
+import java.nio.charset.StandardCharsets;
 import java.util.HashMap;
 import java.util.Map;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-
 public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
   private static Notebook notebook;
 
   private static ClientConfig clientConfig;
   private static ZeppelinClient zeppelinClient;
 
-  @BeforeClass
+  @BeforeAll
   public static void setUp() throws Exception {
     System.setProperty(ZeppelinConfiguration.ConfVars.ZEPPELIN_HELIUM_REGISTRY.getVarName(),
             "helium");
@@ -64,22 +64,23 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     zeppelinClient = new ZeppelinClient(clientConfig);
   }
 
-  @AfterClass
+  @AfterAll
   public static void destroy() throws Exception {
     AbstractTestRestApi.shutDown();
   }
 
   @Test
-  public void testZeppelinVersion() throws Exception {
+  void testZeppelinVersion() throws Exception {
     String version = zeppelinClient.getVersion();
     LOG.info("Zeppelin version: " + version);
+    assertNotNull(version);
   }
 
   @Test
-  public void testImportNote() throws Exception {
-    String noteContent = IOUtils.toString(ZeppelinClientIntegrationTest.class.getResource("/Test_Note.zpln"));
+  void testImportNote() throws Exception {
+    String noteContent = IOUtils.toString(ZeppelinClientIntegrationTest.class.getResource("/Test_Note.zpln"), StandardCharsets.UTF_8);
     String noteId = zeppelinClient.importNote("/imported_notes/note_1", noteContent);
-    assertNotNull("Import note failed because returned noteId is null", noteId);
+    assertNotNull(noteId, "Import note failed because returned noteId is null");
 
     NoteResult noteResult = zeppelinClient.queryNoteResult(noteId);
     assertFalse(noteResult.isRunning());
@@ -94,7 +95,7 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
       fail("Should fail to import note to the same notePath");
     } catch (Exception e) {
       e.printStackTrace();
-      assertTrue(e.getMessage(), e.getMessage().contains("Note '/imported_notes/note_1' existed"));
+      assertTrue(e.getMessage().contains("Note '/imported_notes/note_1' existed"), e.getMessage());
     }
 
     // import invalid noteContent
@@ -103,21 +104,25 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
       fail("Should fail to import note with invalid note content");
     } catch (Exception e) {
       e.printStackTrace();
-      assertTrue(e.getMessage(), e.getMessage().contains("Invalid JSON"));
+      assertTrue(e.getMessage().contains("Invalid JSON"), e.getMessage());
     }
   }
 
   @Test
-  public void testNoteOperation() throws Exception {
+  void testNoteOperation() throws Exception {
     String noteId = zeppelinClient.createNote("/project_1/note1");
-    assertNotNull(notebook.getNote(noteId));
+    notebook.processNote(noteId,
+      note -> {
+        assertNotNull(note);
+        return null;
+      });
 
     // create duplicated note
     try {
       zeppelinClient.createNote("/project_1/note1");
       fail("Should fail to create duplicated note");
     } catch (Exception e) {
-      assertTrue(e.getMessage(), e.getMessage().contains("existed"));
+      assertTrue(e.getMessage().contains("existed"), e.getMessage());
     }
 
     // query NoteResult
@@ -132,7 +137,7 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
       zeppelinClient.queryNoteResult("unknown-noteId");
       fail("Should fail to query non-existed note");
     } catch (Exception e) {
-      assertTrue(e.getMessage(), e.getMessage().contains("No such note"));
+      assertTrue(e.getMessage().contains("No such note"), e.getMessage());
     }
 
     zeppelinClient.deleteNote(noteId);
@@ -142,45 +147,64 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
       zeppelinClient.deleteNote(noteId);
       fail("Should fail to delete non-existed note");
     } catch (Exception e) {
-      assertTrue(e.getMessage(), e.getMessage().contains("No such note"));
+      assertTrue(e.getMessage().contains("No such note"), e.getMessage());
     }
   }
 
   @Test
-  public void testCloneNote() throws Exception {
+  void testCloneNote() throws Exception {
     String noteId = zeppelinClient.createNote("/clone_note_test/note1");
-    Note note1 = notebook.getNote(noteId);
-    assertNotNull(note1);
-
+    notebook.processNote(noteId,
+      note1 -> {
+        assertNotNull(note1);
+        return null;
+      });
     zeppelinClient.addParagraph(noteId, "title_1", "text_1");
-    assertEquals(1, note1.getParagraphCount());
+    notebook.processNote(noteId,
+      note1 -> {
+        assertEquals(1, note1.getParagraphCount());
+        return null;
+      });
 
     String clonedNoteId = zeppelinClient.cloneNote(noteId, "/clone_note_test/cloned_note1");
-    Note clonedNote = notebook.getNote(clonedNoteId);
-    assertEquals(1, clonedNote.getParagraphCount());
-    assertEquals("title_1", clonedNote.getParagraph(0).getTitle());
-    assertEquals("text_1", clonedNote.getParagraph(0).getText());
+    notebook.processNote(clonedNoteId,
+      clonedNote -> {
+        assertEquals(1, clonedNote.getParagraphCount());
+        assertEquals("title_1", clonedNote.getParagraph(0).getTitle());
+        assertEquals("text_1", clonedNote.getParagraph(0).getText());
+        return null;
+      });
   }
 
   @Test
-  public void testRenameNote() throws Exception {
+  void testRenameNote() throws Exception {
     String noteId = zeppelinClient.createNote("/rename_note_test/note1");
-    Note note1 = notebook.getNote(noteId);
-    assertNotNull(note1);
+    notebook.processNote(noteId,
+      note1 -> {
+        assertNotNull(note1);
+        return null;
+      });
 
     zeppelinClient.addParagraph(noteId, "title_1", "text_1");
-    assertEquals(1, note1.getParagraphCount());
+    notebook.processNote(noteId,
+      note1 -> {
+        assertEquals(1, note1.getParagraphCount());
+        return null;
+      });
 
     zeppelinClient.renameNote(noteId, "/rename_note_test/note1_renamed");
-    Note renamedNote = notebook.getNote(noteId);
-    assertEquals("/rename_note_test/note1_renamed", renamedNote.getPath());
-    assertEquals(1, renamedNote.getParagraphCount());
-    assertEquals("title_1", renamedNote.getParagraph(0).getTitle());
-    assertEquals("text_1", renamedNote.getParagraph(0).getText());
+    notebook.processNote(noteId,
+      renamedNote -> {
+        assertEquals("/rename_note_test/note1_renamed", renamedNote.getPath());
+        assertEquals(1, renamedNote.getParagraphCount());
+        assertEquals("title_1", renamedNote.getParagraph(0).getTitle());
+        assertEquals("text_1", renamedNote.getParagraph(0).getText());
+        return null;
+      });
   }
 
   @Test
-  public void testExecuteParagraph() throws Exception {
+  void testExecuteParagraph() throws Exception {
     // run paragraph succeed
     String noteId = zeppelinClient.createNote("/test/note_1");
     String paragraphId = zeppelinClient.addParagraph(noteId, "run sh", "%sh echo 'hello world'");
@@ -192,10 +216,10 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     assertEquals("hello world\n", paragraphResult.getResults().get(0).getData());
 
     // run paragraph succeed with dynamic forms
-    paragraphId = zeppelinClient.addParagraph(noteId, "run sh", "%sh echo 'hello ${name=abc}'");
+    paragraphId = zeppelinClient.addParagraph(noteId, "run sh", "%sh(form=simple) echo 'hello ${name=abc}'");
     paragraphResult = zeppelinClient.executeParagraph(noteId, paragraphId);
     assertEquals(paragraphId, paragraphResult.getParagraphId());
-    assertEquals(paragraphResult.toString(), Status.FINISHED, paragraphResult.getStatus());
+    assertEquals(Status.FINISHED, paragraphResult.getStatus(), paragraphResult.toString());
     assertEquals(1, paragraphResult.getResults().size());
     assertEquals("TEXT", paragraphResult.getResults().get(0).getType());
     assertEquals("hello abc\n", paragraphResult.getResults().get(0).getData());
@@ -217,9 +241,9 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     assertEquals(Status.ERROR, paragraphResult.getStatus());
     assertEquals(2, paragraphResult.getResults().size());
     assertEquals("TEXT", paragraphResult.getResults().get(0).getType());
-    assertTrue(paragraphResult.getResults().get(0).getData(), paragraphResult.getResults().get(0).getData().contains("command not found"));
+    assertTrue(paragraphResult.getResults().get(0).getData().contains("command not found"), paragraphResult.getResults().get(0).getData());
     assertEquals("TEXT", paragraphResult.getResults().get(1).getType());
-    assertTrue(paragraphResult.getResults().get(1).getData(), paragraphResult.getResults().get(1).getData().contains("ExitValue"));
+    assertTrue(paragraphResult.getResults().get(1).getData().contains("ExitValue"), paragraphResult.getResults().get(1).getData());
 
     // run non-existed interpreter
     paragraphId = zeppelinClient.addParagraph(noteId, "run sh", "%non_existed hello");
@@ -228,19 +252,19 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     assertEquals(Status.ERROR, paragraphResult.getStatus());
     assertEquals(1, paragraphResult.getResults().size());
     assertEquals("TEXT", paragraphResult.getResults().get(0).getType());
-    assertTrue(paragraphResult.getResults().get(0).getData(), paragraphResult.getResults().get(0).getData().contains("Interpreter non_existed not found"));
+    assertTrue(paragraphResult.getResults().get(0).getData().contains("Interpreter non_existed not found"), paragraphResult.getResults().get(0).getData());
 
     // run non-existed paragraph
     try {
       zeppelinClient.executeParagraph(noteId, "invalid_paragraph_id");
       fail("Should fail to run non-existed paragraph");
     } catch (Exception e) {
-      assertTrue(e.getMessage(), e.getMessage().contains("No such paragraph"));
+      assertTrue(e.getMessage().contains("No such paragraph"), e.getMessage());
     }
   }
 
   @Test
-  public void testSubmitParagraph() throws Exception {
+  void testSubmitParagraph() throws Exception {
     String noteId = zeppelinClient.createNote("/test/note_2");
     String paragraphId = zeppelinClient.addParagraph(noteId, "run sh", "%sh echo 'hello world'");
     zeppelinClient.submitParagraph(noteId, paragraphId);
@@ -252,11 +276,11 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     assertEquals("hello world\n", paragraphResult.getResults().get(0).getData());
 
     // submit paragraph succeed with dynamic forms
-    paragraphId = zeppelinClient.addParagraph(noteId, "run sh", "%sh echo 'hello ${name=abc}'");
+    paragraphId = zeppelinClient.addParagraph(noteId, "run sh", "%sh(form=simple) echo 'hello ${name=abc}'");
     zeppelinClient.submitParagraph(noteId, paragraphId);
     paragraphResult = zeppelinClient.waitUtilParagraphFinish(noteId, paragraphId, 10 * 1000);
     assertEquals(paragraphId, paragraphResult.getParagraphId());
-    assertEquals(paragraphResult.toString(), Status.FINISHED, paragraphResult.getStatus());
+    assertEquals(Status.FINISHED, paragraphResult.getStatus(), paragraphResult.toString());
     assertEquals(1, paragraphResult.getResults().size());
     assertEquals("TEXT", paragraphResult.getResults().get(0).getType());
     assertEquals("hello abc\n", paragraphResult.getResults().get(0).getData());
@@ -281,9 +305,9 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     assertEquals(Status.ERROR, paragraphResult.getStatus());
     assertEquals(2, paragraphResult.getResults().size());
     assertEquals("TEXT", paragraphResult.getResults().get(0).getType());
-    assertTrue(paragraphResult.getResults().get(0).getData(), paragraphResult.getResults().get(0).getData().contains("command not found"));
+    assertTrue(paragraphResult.getResults().get(0).getData().contains("command not found"), paragraphResult.getResults().get(0).getData());
     assertEquals("TEXT", paragraphResult.getResults().get(1).getType());
-    assertTrue(paragraphResult.getResults().get(1).getData(), paragraphResult.getResults().get(1).getData().contains("ExitValue"));
+    assertTrue(paragraphResult.getResults().get(1).getData().contains("ExitValue"), paragraphResult.getResults().get(1).getData());
 
     // run non-existed interpreter
     paragraphId = zeppelinClient.addParagraph(noteId, "run sh", "%non_existed hello");
@@ -293,24 +317,24 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     assertEquals(Status.ERROR, paragraphResult.getStatus());
     assertEquals(1, paragraphResult.getResults().size());
     assertEquals("TEXT", paragraphResult.getResults().get(0).getType());
-    assertTrue(paragraphResult.getResults().get(0).getData(), paragraphResult.getResults().get(0).getData().contains("Interpreter non_existed not found"));
+    assertTrue(paragraphResult.getResults().get(0).getData().contains("Interpreter non_existed not found"), paragraphResult.getResults().get(0).getData());
 
     // run non-existed paragraph
     try {
       zeppelinClient.submitParagraph(noteId, "invalid_paragraph_id");
       fail("Should fail to run non-existed paragraph");
     } catch (Exception e) {
-      assertTrue(e.getMessage(), e.getMessage().contains("No such paragraph"));
+      assertTrue(e.getMessage().contains("No such paragraph"), e.getMessage());
     }
   }
 
   @Test
-  public void testExecuteNote() throws Exception {
+  void testExecuteNote() throws Exception {
     try {
       zeppelinClient.executeNote("unknown_id");
       fail("Should fail to submit non-existed note");
     } catch (Exception e) {
-      assertTrue(e.getMessage(), e.getMessage().contains("No such note"));
+      assertTrue(e.getMessage().contains("No such note"), e.getMessage());
     }
     String noteId = zeppelinClient.createNote("/test/note_3");
     String p0Id = zeppelinClient.addParagraph(noteId, "run sh", "%sh echo 'hello world'");
@@ -325,7 +349,7 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     assertEquals("hello world\n", p0.getResults().get(0).getData());
 
     // update paragraph with dynamic forms
-    zeppelinClient.updateParagraph(noteId, p0Id, "run sh", "%sh echo 'hello ${name=abc}'");
+    zeppelinClient.updateParagraph(noteId, p0Id, "run sh", "%sh(form=simple) echo 'hello ${name=abc}'");
     noteResult = zeppelinClient.executeNote(noteId);
     assertEquals(noteId, noteResult.getNoteId());
     assertEquals(false, noteResult.isRunning());
@@ -364,9 +388,9 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     ParagraphResult p1 = noteResult.getParagraphResultList().get(1);
     assertEquals(Status.ERROR, p1.getStatus());
     assertEquals("TEXT", p1.getResults().get(0).getType());
-    assertTrue(p1.getResults().get(0).getData(), p1.getResults().get(0).getData().contains("command not found"));
+    assertTrue(p1.getResults().get(0).getData().contains("command not found"), p1.getResults().get(0).getData());
     assertEquals("TEXT", p1.getResults().get(1).getType());
-    assertTrue(p1.getResults().get(1).getData(), p1.getResults().get(1).getData().contains("ExitValue"));
+    assertTrue(p1.getResults().get(1).getData().contains("ExitValue"), p1.getResults().get(1).getData());
 
     // p2 will be skipped because p1 fails.
     ParagraphResult p2 = noteResult.getParagraphResultList().get(2);
@@ -375,12 +399,12 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
   }
 
   @Test
-  public void testSubmitNote() throws Exception {
+  void testSubmitNote() throws Exception {
     try {
       zeppelinClient.submitNote("unknown_id");
       fail("Should fail to submit non-existed note");
     } catch (Exception e) {
-      assertTrue(e.getMessage(), e.getMessage().contains("No such note"));
+      assertTrue(e.getMessage().contains("No such note"), e.getMessage());
     }
     String noteId = zeppelinClient.createNote("/test/note_4");
     String p0Id = zeppelinClient.addParagraph(noteId, "run sh", "%sh echo 'hello world'");
@@ -396,7 +420,7 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     assertEquals("hello world\n", p0.getResults().get(0).getData());
 
     // update paragraph with dynamic forms
-    zeppelinClient.updateParagraph(noteId, p0Id, "run sh", "%sh sleep 5\necho 'hello ${name=abc}'");
+    zeppelinClient.updateParagraph(noteId, p0Id, "run sh", "%sh(form=simple) sleep 5\necho 'hello ${name=abc}'");
     noteResult = zeppelinClient.submitNote(noteId);
     assertEquals(true, noteResult.isRunning());
     noteResult = zeppelinClient.waitUntilNoteFinished(noteId);
@@ -438,9 +462,9 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
     ParagraphResult p1 = noteResult.getParagraphResultList().get(1);
     assertEquals(Status.ERROR, p1.getStatus());
     assertEquals("TEXT", p1.getResults().get(0).getType());
-    assertTrue(p1.getResults().get(0).getData(), p1.getResults().get(0).getData().contains("command not found"));
+    assertTrue(p1.getResults().get(0).getData().contains("command not found"), p1.getResults().get(0).getData());
     assertEquals("TEXT", p1.getResults().get(1).getType());
-    assertTrue(p1.getResults().get(1).getData(), p1.getResults().get(1).getData().contains("ExitValue"));
+    assertTrue(p1.getResults().get(1).getData().contains("ExitValue"), p1.getResults().get(1).getData());
 
     // p2 will be skipped because p1 fails.
     ParagraphResult p2 = noteResult.getParagraphResultList().get(2);
@@ -449,7 +473,7 @@ public class ZeppelinClientIntegrationTest extends AbstractTestRestApi {
   }
 
   @Test
-  public void testSession() throws Exception {
+  void testSession() throws Exception {
     SessionInfo sessionInfo = zeppelinClient.getSession("invalid_session");
     assertNull(sessionInfo);
 
