@@ -19,10 +19,10 @@ package org.apache.zeppelin.display;
 
 /**
  *
- *
+ * Listener class for angular object operations, such as add, update, remove.
  */
 public interface AngularObjectRegistryListener {
-  public void onAdd(String interpreterGroupId, AngularObject object);
-  public void onUpdate(String interpreterGroupId, AngularObject object);
-  public void onRemove(String interpreterGroupId, String name, String noteId, String paragraphId);
+  void onAddAngularObject(String interpreterGroupId, AngularObject angularObject);
+  void onUpdateAngularObject(String interpreterGroupId, AngularObject angularObject);
+  void onRemoveAngularObject(String interpreterGroupId, AngularObject angularObject);
 }
