@@ -24,10 +24,10 @@ public interface InterpreterHookListener {
   /**
    * Prepends pre-execute hook code to the script that will be interpreted
    */
-  public void onPreExecute(String script);
+  void onPreExecute(String script);
   
   /**
    * Appends post-execute hook code to the script that will be interpreted
    */
-  public void onPostExecute(String script);
+  void onPostExecute(String script);
 }
