@@ -178,6 +178,10 @@ public class YarnRemoteInterpreterProcess extends RemoteInterpreterProcess {
       this.appId = appResponse.getApplicationId();
       ApplicationSubmissionContext appContext = yarnApplication.getApplicationSubmissionContext();
       appContext = createApplicationSubmissionContext(appContext);
+      String YARN_NODE_LABEL_EXPRESSION = "zeppelin.interpreter.yarn.node.label.expression";
+      if(StringUtils.isNotEmpty(properties.getProperty(YARN_NODE_LABEL_EXPRESSION,""))) {
+        appContext.setNodeLabelExpression(properties.getProperty(YARN_NODE_LABEL_EXPRESSION));
+      }
       yarnClient.submitApplication(appContext);
 
       long start = System.currentTimeMillis();
@@ -629,6 +633,12 @@ public class YarnRemoteInterpreterProcess extends RemoteInterpreterProcess {
     return this.port;
   }
 
+  @Override
+  public boolean isAlive() {
+    //TODO(ZEPPELIN-5876): Implement it more accurately
+    return isRunning();
+  }
+
   @Override
   public boolean isRunning() {
     return isYarnAppRunning.get();
