@@ -16,20 +16,17 @@
  */
 package org.apache.zeppelin.rest.message;
 
-import com.google.gson.Gson;
-
-import org.apache.zeppelin.common.JsonSerializable;
-
 /**
  *  CronRequest rest api request message.
  */
-public class CronRequest implements JsonSerializable {
-  private static final Gson gson = new Gson();
+public class CronRequest {
 
-  private String cron;
-  private Boolean releaseResource;
+  private final String cron;
+  private final Boolean releaseResource;
 
-  public CronRequest (){
+  public CronRequest (String cron, Boolean releaseResource){
+    this.cron = cron;
+    this.releaseResource = releaseResource;
   }
 
   public String getCronString() {
@@ -42,12 +39,4 @@ public class CronRequest implements JsonSerializable {
     }
     return releaseResource;
   }
-
-  public String toJson() {
-    return gson.toJson(this);
-  }
-
-  public static CronRequest fromJson(String json) {
-    return gson.fromJson(json, CronRequest.class);
-  }
 }
