@@ -27,10 +27,7 @@ import java.nio.file.DirectoryStream;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Optional;
-import java.util.StringJoiner;
+import java.util.*;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
@@ -46,8 +43,6 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import java.io.File;
-import java.util.Map;
-import java.util.Properties;
 
 /**
  * Spark specific launcher.
@@ -67,16 +62,26 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
   public Map<String, String> buildEnvFromProperties(InterpreterLaunchContext context) throws IOException {
     Map<String, String> env = super.buildEnvFromProperties(context);
     Properties sparkProperties = new Properties();
-    String spMaster = getSparkMaster();
+    String spMaster = getSparkMaster(context);
     if (spMaster != null) {
       sparkProperties.put(SPARK_MASTER_KEY, spMaster);
     }
+    Properties properties = context.getProperties();
     for (String key : properties.stringPropertyNames()) {
       String propValue = properties.getProperty(key);
       if (RemoteInterpreterUtils.isEnvString(key) && !StringUtils.isBlank(propValue)) {
         env.put(key, propValue);
       }
       if (isSparkConf(key, propValue)) {
+        // There is already initial value following --driver-java-options when SparkInterpreter launches.
+        // Values in sparkProperties would be added by --conf,
+        // and --conf spark.driver.extraJavaOptions would conflict with --driver-java-options.
+        // Therefore we add values of spark.driver.extraJavaOptions following --driver-java-options
+        // instead of into sparkProperties.
+        if (Objects.equals("spark.driver.extraJavaOptions", key)) {
+          env.put("SPARK_DRIVER_EXTRAJAVAOPTIONS_CONF", (String) properties.remove(key));
+          continue;
+        }
         sparkProperties.setProperty(key, propValue);
       }
     }
@@ -87,27 +92,32 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
       sparkProperties.setProperty("spark.app.name", context.getInterpreterGroupId());
     }
 
-    setupPropertiesForPySpark(sparkProperties);
-    setupPropertiesForSparkR(sparkProperties);
+    setupPropertiesForPySpark(sparkProperties, context);
+    setupPropertiesForSparkR(sparkProperties, context);
 
     String condaEnvName = context.getProperties().getProperty("zeppelin.interpreter.conda.env.name");
     if (StringUtils.isNotBlank(condaEnvName)) {
-      if (!isYarnCluster()) {
+      if (!isYarnCluster(context)) {
         throw new IOException("zeppelin.interpreter.conda.env.name only works for yarn-cluster mode");
       }
       sparkProperties.setProperty("spark.pyspark.python", condaEnvName + "/bin/python");
     }
 
-    if (isYarnMode() && getDeployMode().equals("cluster")) {
+    if (isYarnCluster(context)) {
       env.put("ZEPPELIN_SPARK_YARN_CLUSTER", "true");
       sparkProperties.setProperty("spark.yarn.submit.waitAppCompletion", "false");
+      // Need to set `zeppelin.interpreter.forceShutdown` in interpreter properties directly
+      // instead of updating sparkProperties.
+      // Because `zeppelin.interpreter.forceShutdown` is initialized in RemoteInterpreterServer
+      // before SparkInterpreter is created.
+      context.getProperties().put("zeppelin.interpreter.forceShutdown", "false");
     } else if (zConf.isOnlyYarnCluster()){
       throw new IOException("Only yarn-cluster mode is allowed, please set " +
               ZeppelinConfiguration.ConfVars.ZEPPELIN_SPARK_ONLY_YARN_CLUSTER.getVarName() +
               " to false if you want to use other modes.");
     }
 
-    if (isYarnMode() && getDeployMode().equals("cluster")) {
+    if (isYarnMode(context) && getDeployMode(context).equals("cluster")) {
       if (sparkProperties.containsKey("spark.files")) {
         sparkProperties.put("spark.files", sparkProperties.getProperty("spark.files") + "," +
             zConf.getConfDir() + "/log4j_yarn_cluster.properties");
@@ -120,15 +130,17 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
 
     String scalaVersion = null;
     try {
-      scalaVersion = detectSparkScalaVersion(getEnv("SPARK_HOME"), env);
-      LOGGER.info("Scala version: {}", scalaVersion);
+      String sparkHome = getEnv("SPARK_HOME", context);
+      LOGGER.info("SPARK_HOME: {}", sparkHome);
+      scalaVersion = detectSparkScalaVersion(sparkHome, env);
+      LOGGER.info("Scala version for Spark: {}", scalaVersion);
       context.getProperties().put("zeppelin.spark.scala.version", scalaVersion);
     } catch (Exception e) {
       throw new IOException("Fail to detect scala version, the reason is:"+ e.getMessage());
     }
 
-    if (isYarnMode()
-        && getDeployMode().equals("cluster")) {
+    if (isYarnMode(context)
+      && getDeployMode(context).equals("cluster")) {
       try {
         List<String> additionalJars = new ArrayList<>();
         Path localRepoPath =
@@ -202,7 +214,7 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
     // It is encouraged to set env in interpreter setting, but just for backward compatibility,
     // we also fallback to zeppelin-env.sh if it is not specified in interpreter setting.
     for (String envName : new String[]{"SPARK_HOME", "SPARK_CONF_DIR", "HADOOP_CONF_DIR"})  {
-      String envValue = getEnv(envName);
+      String envValue = getEnv(envName, context);
       if (!StringUtils.isBlank(envValue)) {
         env.put(envName, envValue);
       }
@@ -224,9 +236,9 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
     env.put("PYSPARK_PIN_THREAD", "true");
 
     // ZEPPELIN_INTP_CLASSPATH
-    String sparkConfDir = getEnv("SPARK_CONF_DIR");
+    String sparkConfDir = getEnv("SPARK_CONF_DIR", context);
     if (StringUtils.isBlank(sparkConfDir)) {
-      String sparkHome = getEnv("SPARK_HOME");
+      String sparkHome = getEnv("SPARK_HOME", context);
       sparkConfDir = sparkHome + "/conf";
     }
     Properties sparkDefaultProperties = new Properties();
@@ -241,7 +253,7 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
       LOGGER.warn("spark-defaults.conf doesn't exist: {}", sparkDefaultFile.getAbsolutePath());
     }
 
-    if (isYarnMode()) {
+    if (isYarnMode(context)) {
       boolean runAsLoginUser = Boolean.parseBoolean(context
               .getProperties()
               .getProperty("zeppelin.spark.run.asLoginUser", "true"));
@@ -267,12 +279,10 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
     Matcher matcher = pattern.matcher(processOutput);
     if (matcher.find()) {
       String scalaVersion = matcher.group(1);
-      if (scalaVersion.startsWith("2.10")) {
-        return "2.10";
-      } else if (scalaVersion.startsWith("2.11")) {
-        return "2.11";
-      } else if (scalaVersion.startsWith("2.12")) {
+      if (scalaVersion.startsWith("2.12")) {
         return "2.12";
+      } else if (scalaVersion.startsWith("2.13")) {
+        return "2.13";
       } else {
         throw new Exception("Unsupported scala version: " + scalaVersion);
       }
@@ -282,37 +292,26 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
   }
 
   private String detectSparkScalaVersionByReplClass(String sparkHome) throws Exception {
-    File sparkLibFolder = new File(sparkHome + "/lib");
-    if (sparkLibFolder.exists()) {
-      // spark 1.6 if spark/lib exists
-      File[] sparkAssemblyJars = new File(sparkHome + "/lib").listFiles(new FilenameFilter() {
-        @Override
-        public boolean accept(File dir, String name) {
-          return name.contains("spark-assembly");
-        }
-      });
-      if (sparkAssemblyJars.length == 0) {
-        throw new Exception("No spark assembly file found in SPARK_HOME: " + sparkHome);
-      }
-      if (sparkAssemblyJars.length > 1) {
-        throw new Exception("Multiple spark assembly file found in SPARK_HOME: " + sparkHome);
-      }
-      try (URLClassLoader urlClassLoader = new URLClassLoader(new URL[]{sparkAssemblyJars[0].toURI().toURL()});){
-        urlClassLoader.loadClass("org.apache.spark.repl.SparkCommandLine");
-        return "2.10";
-      } catch (ClassNotFoundException e) {
-        return "2.11";
-      }
+    File sparkJarsFolder = new File(sparkHome + "/jars");
+    File[] sparkJarFiles = sparkJarsFolder.listFiles();
+    long sparkReplFileNum =
+            Stream.of(sparkJarFiles).filter(file -> file.getName().contains("spark-repl_")).count();
+    if (sparkReplFileNum == 0) {
+      throw new Exception("No spark-repl jar found in SPARK_HOME: " + sparkHome);
+    }
+    if (sparkReplFileNum > 1) {
+      throw new Exception("Multiple spark-repl jar found in SPARK_HOME: " + sparkHome);
+    }
+    boolean sparkRepl212Exists =
+            Stream.of(sparkJarFiles).anyMatch(file -> file.getName().contains("spark-repl_2.12"));
+    boolean sparkRepl213Exists =
+            Stream.of(sparkJarFiles).anyMatch(file -> file.getName().contains("spark-repl_2.13"));
+    if (sparkRepl212Exists) {
+      return "2.12";
+    } else if (sparkRepl213Exists) {
+      return "2.13";
     } else {
-      // spark 2.x if spark/lib doesn't exists
-      File sparkJarsFolder = new File(sparkHome + "/jars");
-      boolean sparkRepl211Exists =
-              Stream.of(sparkJarsFolder.listFiles()).anyMatch(file -> file.getName().contains("spark-repl_2.11"));
-      if (sparkRepl211Exists) {
-        return "2.11";
-      } else {
-        return "2.10";
-      }
+      throw new Exception("Can not detect the scala version by spark-repl");
     }
   }
 
@@ -323,11 +322,15 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
    * 2. zeppelin-env.sh
    *
    */
-  private String getEnv(String envName) {
-    String env = properties.getProperty(envName);
-    if (env == null) {
+  private String getEnv(String envName, InterpreterLaunchContext context) {
+    String env = context.getProperties().getProperty(envName);
+    if (StringUtils.isBlank(env)) {
       env = System.getenv(envName);
     }
+    if (StringUtils.isBlank(env)) {
+      LOGGER.warn("environment variable: {} is empty", envName);
+    }
+
     return env;
   }
 
@@ -335,8 +338,9 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
     return !StringUtils.isEmpty(key) && key.startsWith("spark.") && !StringUtils.isEmpty(value);
   }
 
-  private void setupPropertiesForPySpark(Properties sparkProperties) {
-    if (isYarnMode()) {
+  private void setupPropertiesForPySpark(Properties sparkProperties,
+    InterpreterLaunchContext context) {
+    if (isYarnMode(context)) {
       sparkProperties.setProperty("spark.yarn.isPython", "true");
     }
   }
@@ -351,12 +355,13 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
     }
   }
 
-  private void setupPropertiesForSparkR(Properties sparkProperties) {
-    if (isYarnMode()) {
-      String sparkHome = getEnv("SPARK_HOME");
+  private void setupPropertiesForSparkR(Properties sparkProperties,
+    InterpreterLaunchContext context) {
+    if (isYarnMode(context)) {
+      String sparkHome = getEnv("SPARK_HOME", context);
       File sparkRBasePath = null;
       if (sparkHome == null) {
-        if (!getSparkMaster().startsWith("local")) {
+        if (!getSparkMaster(context).startsWith("local")) {
           throw new RuntimeException("SPARK_HOME is not specified in interpreter-setting" +
                   " for non-local mode, if you specify it in zeppelin-env.sh, please move that into " +
                   " interpreter setting");
@@ -387,9 +392,10 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
    * 3. use local[*]
    * @return Spark Master string
    */
-  private String getSparkMaster() {
+  private String getSparkMaster(InterpreterLaunchContext context) {
     if (!sparkMaster.isPresent()) {
-      String master = properties.getProperty(SPARK_MASTER_KEY);
+      Properties properties = context.getProperties();
+      String master = context.getProperties().getProperty(SPARK_MASTER_KEY);
       if (master == null) {
         master = properties.getProperty("master");
         if (master == null) {
@@ -403,15 +409,15 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
     return sparkMaster.get();
   }
 
-  private String getDeployMode() {
-    if (getSparkMaster().equals("yarn-client")) {
+  private String getDeployMode(InterpreterLaunchContext context) {
+    if (getSparkMaster(context).equals("yarn-client")) {
       return "client";
-    } else if (getSparkMaster().equals("yarn-cluster")) {
+    } else if (getSparkMaster(context).equals("yarn-cluster")) {
       return "cluster";
-    } else if (getSparkMaster().startsWith("local")) {
+    } else if (getSparkMaster(context).startsWith("local")) {
       return "client";
     } else {
-      String deployMode = properties.getProperty("spark.submit.deployMode");
+      String deployMode = context.getProperties().getProperty("spark.submit.deployMode");
       if (deployMode == null) {
         throw new RuntimeException("master is set as yarn, but spark.submit.deployMode " +
             "is not specified");
@@ -423,15 +429,11 @@ public class SparkInterpreterLauncher extends StandardInterpreterLauncher {
     }
   }
 
-  private boolean isYarnMode() {
-    return getSparkMaster().startsWith("yarn");
+  private boolean isYarnMode(InterpreterLaunchContext context) {
+    return getSparkMaster(context).startsWith("yarn");
   }
 
-  private boolean isYarnCluster() {
-    return isYarnMode() && "cluster".equalsIgnoreCase(getDeployMode());
-  }
-
-  private boolean isYarnClient() {
-    return isYarnMode() && "client".equalsIgnoreCase(getDeployMode());
+  private boolean isYarnCluster(InterpreterLaunchContext context) {
+    return isYarnMode(context) && "cluster".equalsIgnoreCase(getDeployMode(context));
   }
 }
