@@ -17,8 +17,6 @@
 
 package org.apache.zeppelin.notebook;
 
-import com.google.gson.Gson;
-import com.google.gson.GsonBuilder;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
 import org.apache.zeppelin.user.AuthenticationInfo;
 
@@ -33,25 +31,35 @@ import java.util.Set;
  */
 public class NoteAuth {
 
-  private static Gson gson = new GsonBuilder().setPrettyPrinting().create();
+  private final String noteId;
+  private final ZeppelinConfiguration zconf;
 
-  private String noteId;
   private Set<String> readers = new HashSet<>();
   private Set<String> writers = new HashSet<>();
   private Set<String> runners = new HashSet<>();
   private Set<String> owners = new HashSet<>();
 
-  public NoteAuth(String noteId) {
-    this(noteId, AuthenticationInfo.ANONYMOUS);
+  public NoteAuth(String noteId, ZeppelinConfiguration zconf) {
+    this(noteId, AuthenticationInfo.ANONYMOUS, zconf);
   }
 
-  public NoteAuth(String noteId, AuthenticationInfo subject) {
+  public NoteAuth(String noteId, AuthenticationInfo subject, ZeppelinConfiguration zconf) {
     this.noteId = noteId;
+    this.zconf = zconf;
     initPermissions(subject);
   }
 
-  public NoteAuth(String noteId, Map<String, Set<String>> permissions) {
+  /**
+   * Creates a NoteAuth from a map loaded from notebook-authorization.json. At this point it is not possible to distinguish
+   * between a user and a group string, so checkCaseAndConvert must not be used.
+   *
+   * @param noteId
+   * @param permissions
+   * @param zconf
+   */
+  public NoteAuth(String noteId, Map<String, Set<String>> permissions, ZeppelinConfiguration zconf) {
     this.noteId = noteId;
+    this.zconf = zconf;
     this.readers = permissions.getOrDefault("readers", new HashSet<>());
     this.writers = permissions.getOrDefault("writers", new HashSet<>());
     this.runners = permissions.getOrDefault("runners", new HashSet<>());
@@ -61,7 +69,7 @@ public class NoteAuth {
   // used when creating new note
   public void initPermissions(AuthenticationInfo subject) {
     if (!AuthenticationInfo.isAnonymous(subject)) {
-      if (ZeppelinConfiguration.create().isNotebookPublic()) {
+      if (zconf.isNotebookPublic()) {
         // add current user to owners - can be public
         this.owners.add(checkCaseAndConvert(subject.getUser()));
       } else {
@@ -114,7 +122,7 @@ public class NoteAuth {
    * If case conversion is enforced, then change entity names to lower case
    */
   private Set<String> checkCaseAndConvert(Set<String> entities) {
-    if (ZeppelinConfiguration.create().isUsernameForceLowerCase()) {
+    if (zconf.isUsernameForceLowerCase()) {
       Set<String> set2 = new HashSet<>();
       for (String name : entities) {
         set2.add(name.toLowerCase());
@@ -126,7 +134,7 @@ public class NoteAuth {
   }
 
   private String checkCaseAndConvert(String entity) {
-    if (ZeppelinConfiguration.create().isUsernameForceLowerCase()) {
+    if (zconf.isUsernameForceLowerCase()) {
       return entity.toLowerCase();
     } else {
       return entity;
@@ -141,13 +149,4 @@ public class NoteAuth {
     map.put("owners", owners);
     return map;
   }
-
-  public String toJson() {
-    return gson.toJson(this);
-  }
-
-  public static NoteAuth fromJson(String json) {
-    return gson.fromJson(json, NoteAuth.class);
-  }
-
 }
